Class: Google::Ads::DataManager::V1::AdIdentifiers
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::AdIdentifiers
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/event.rb
Overview
Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).
Instance Attribute Summary collapse
-
#dclid ⇒ ::String
Optional.
-
#encrypted_user_ids ⇒ ::Array<::Google::Ads::DataManager::V1::EncryptedUserId>
Optional.
-
#gbraid ⇒ ::String
Optional.
-
#gclid ⇒ ::String
Optional.
-
#impression_id ⇒ ::String
Optional.
-
#landing_page_device_info ⇒ ::Google::Ads::DataManager::V1::DeviceInfo
Optional.
-
#match_id ⇒ ::String
Optional.
-
#mobile_device_id ⇒ ::String
Optional.
-
#session_attributes ⇒ ::String
Optional.
-
#wbraid ⇒ ::String
Optional.
Instance Attribute Details
#dclid ⇒ ::String
Returns Optional. The display click ID associated with this event.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encrypted_user_ids ⇒ ::Array<::Google::Ads::DataManager::V1::EncryptedUserId>
Returns Optional. Any number of encrypted user IDs.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gbraid ⇒ ::String
Returns Optional. The click identifier for clicks associated with app events and originating from iOS devices starting with iOS14.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gclid ⇒ ::String
Returns Optional. The Google click ID (gclid) associated with this event.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#impression_id ⇒ ::String
Returns Optional. The impression ID associated with this event.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#landing_page_device_info ⇒ ::Google::Ads::DataManager::V1::DeviceInfo
Returns Optional. Information gathered about the device being used (if any) at the time of landing onto the advertiser’s site after interacting with the ad.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#match_id ⇒ ::String
Returns Optional. The match ID field used to join this event with a previous event.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mobile_device_id ⇒ ::String
Returns Optional. The mobile identifier for advertisers. This would be IDFA on iOS, AdID on Android, or other platforms’ identifiers for advertisers.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#session_attributes ⇒ ::String
Returns Optional. Session attributes for event attribution and modeling.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#wbraid ⇒ ::String
Returns Optional. The click identifier for clicks associated with web events and originating from iOS devices starting with iOS14.
158 159 160 161 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 158 class AdIdentifiers include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |