Class: Google::Ads::DataManager::V1::AddressInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_data.rb

Overview

Address information for the user.

Instance Attribute Summary collapse

Instance Attribute Details

#family_name::String

Returns Required. Family (last) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256.

Returns:

  • (::String)

    Required. Family (last) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256.



77
78
79
80
# File 'proto_docs/google/ads/datamanager/v1/user_data.rb', line 77

class AddressInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#given_name::String

Returns Required. Given (first) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256.

Returns:

  • (::String)

    Required. Given (first) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256.



77
78
79
80
# File 'proto_docs/google/ads/datamanager/v1/user_data.rb', line 77

class AddressInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#postal_code::String

Returns Required. The postal code of the user's address.

Returns:

  • (::String)

    Required. The postal code of the user's address.



77
78
79
80
# File 'proto_docs/google/ads/datamanager/v1/user_data.rb', line 77

class AddressInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#region_code::String

Returns Required. The 2-letter region code in ISO-3166-1 alpha-2 of the user's address.

Returns:

  • (::String)

    Required. The 2-letter region code in ISO-3166-1 alpha-2 of the user's address.



77
78
79
80
# File 'proto_docs/google/ads/datamanager/v1/user_data.rb', line 77

class AddressInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end