Class: Google::Ads::DataManager::V1::Baseline

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/insights_service.rb

Overview

Baseline criteria against which insights are compared.

Defined Under Namespace

Classes: Location

Instance Attribute Summary collapse

Instance Attribute Details

#baseline_location::Google::Ads::DataManager::V1::Baseline::Location

Returns The baseline location of the request. Baseline location is an OR-list of the requested regions.

Note: The following fields are mutually exclusive: baseline_location, location_auto_detection_enabled. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Ads::DataManager::V1::Baseline::Location)

    The baseline location of the request. Baseline location is an OR-list of the requested regions.

    Note: The following fields are mutually exclusive: baseline_location, location_auto_detection_enabled. If a field in that set is populated, all other fields in the set will automatically be cleared.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/ads/datamanager/v1/insights_service.rb', line 53

class Baseline
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The baseline location of the request. Baseline location is on OR-list of
  # ISO 3166-1 alpha-2 region codes of the requested regions.
  # @!attribute [rw] region_codes
  #   @return [::Array<::String>]
  #     List of ISO 3166-1 alpha-2 region codes.
  class Location
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#location_auto_detection_enabled::Boolean

Returns If set to true, the service will try to automatically detect the baseline location for insights.

Note: The following fields are mutually exclusive: location_auto_detection_enabled, baseline_location. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    If set to true, the service will try to automatically detect the baseline location for insights.

    Note: The following fields are mutually exclusive: location_auto_detection_enabled, baseline_location. If a field in that set is populated, all other fields in the set will automatically be cleared.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/ads/datamanager/v1/insights_service.rb', line 53

class Baseline
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The baseline location of the request. Baseline location is on OR-list of
  # ISO 3166-1 alpha-2 region codes of the requested regions.
  # @!attribute [rw] region_codes
  #   @return [::Array<::String>]
  #     List of ISO 3166-1 alpha-2 region codes.
  class Location
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end