Class: Google::Ads::DataManager::V1::CartData

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/cart_data.rb

Overview

The cart data associated with the event.

Instance Attribute Summary collapse

Instance Attribute Details

#coupon_codes::Array<::String>

Returns Optional. The list of coupon codes that were applied to the cart. Cart-level and item-level coupon codes are independent.

If the event is for a Google Analytics destination, only provide a single coupon code. Google Analytics ignores additional coupon codes.

Returns:

  • (::Array<::String>)

    Optional. The list of coupon codes that were applied to the cart. Cart-level and item-level coupon codes are independent.

    If the event is for a Google Analytics destination, only provide a single coupon code. Google Analytics ignores additional coupon codes.



49
50
51
52
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 49

class CartData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#items::Array<::Google::Ads::DataManager::V1::Item>

Returns Optional. The list of items associated with the event.

Returns:



49
50
51
52
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 49

class CartData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#merchant_feed_label::String

Returns Optional. The Merchant Center feed label associated with the feed of the items.

Returns:

  • (::String)

    Optional. The Merchant Center feed label associated with the feed of the items.



49
50
51
52
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 49

class CartData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#merchant_feed_language_code::String

Returns Optional. The language code in ISO 639-1 associated with the Merchant Center feed of the items.where your items are uploaded.

Returns:

  • (::String)

    Optional. The language code in ISO 639-1 associated with the Merchant Center feed of the items.where your items are uploaded.



49
50
51
52
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 49

class CartData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#merchant_id::String

Returns Optional. The Merchant Center ID associated with the items.

Returns:

  • (::String)

    Optional. The Merchant Center ID associated with the items.



49
50
51
52
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 49

class CartData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#transaction_discount::Float

Returns Optional. The sum of all discounts associated with the transaction.

Returns:

  • (::Float)

    Optional. The sum of all discounts associated with the transaction.



49
50
51
52
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 49

class CartData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end