Class: Google::Ads::DataManager::V1::CreateUserListGlobalLicenseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb

Overview

Request to create a UserListGlobalLicense resource.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The account that owns the user list being licensed. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}.

Returns:

  • (::String)

    Required. The account that owns the user list being licensed. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}



34
35
36
37
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 34

class CreateUserListGlobalLicenseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_list_global_license::Google::Ads::DataManager::V1::UserListGlobalLicense

Returns Required. The user list global license to create.

Returns:



34
35
36
37
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 34

class CreateUserListGlobalLicenseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end