Class: Google::Ads::DataManager::V1::CreateUserListRequest
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::CreateUserListRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list_service.rb
Overview
Request message for CreateUserList.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#user_list ⇒ ::Google::Ads::DataManager::V1::UserList
Required.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent account where this user list will be created. Format: accountTypes/{account_type}/accounts/{account}.
111 112 113 114 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 111 class CreateUserListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_list ⇒ ::Google::Ads::DataManager::V1::UserList
Returns Required. The user list to create.
111 112 113 114 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 111 class CreateUserListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. If true, the request is validated but not executed.
111 112 113 114 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 111 class CreateUserListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |