Class: Google::Ads::DataManager::V1::CustomVariable

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/event.rb

Overview

Custom variable for ads conversions.

Instance Attribute Summary collapse

Instance Attribute Details

#destination_references::Array<::String>

Returns Optional. Reference string used to determine which of the Event.destination_references the custom variable should be sent to. If empty, the Event.destination_references will be used.

Returns:



145
146
147
148
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 145

class CustomVariable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::String

Returns Optional. The value to store for the custom variable.

Returns:

  • (::String)

    Optional. The value to store for the custom variable.



145
146
147
148
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 145

class CustomVariable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#variable::String

Returns Optional. The name of the custom variable to set. If the variable is not found for the given destination, it will be ignored.

Returns:

  • (::String)

    Optional. The name of the custom variable to set. If the variable is not found for the given destination, it will be ignored.



145
146
147
148
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 145

class CustomVariable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end