Class: Google::Ads::DataManager::V1::DeleteUserListRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_service.rb

Overview

Request message for DeleteUserList.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the user list to delete. Format: accountTypes/{account_type}/accounts/{account}/userLists/{user_list}.

Returns:

  • (::String)

    Required. The name of the user list to delete. Format: accountTypes/{account_type}/accounts/{account}/userLists/{user_list}



144
145
146
147
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 144

class DeleteUserListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. If true, the request is validated but not executed.

Returns:

  • (::Boolean)

    Optional. If true, the request is validated but not executed.



144
145
146
147
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 144

class DeleteUserListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end