Class: Google::Ads::DataManager::V1::DeviceInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/device_info.rb

Overview

Information about the device being used (if any) when the event happened.

Instance Attribute Summary collapse

Instance Attribute Details

#brand::String

Returns Optional. The brand of the device.

Returns:

  • (::String)

    Optional. The brand of the device.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#browser::String

Returns Optional. The brand or type of the browser.

Returns:

  • (::String)

    Optional. The brand or type of the browser.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#browser_version::String

Returns Optional. The version of the browser.

Returns:

  • (::String)

    Optional. The version of the browser.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#category::String

Returns Optional. The category of device. For example, “desktop”, “tablet”, “mobile”, “smart TV”.

Returns:

  • (::String)

    Optional. The category of device. For example, “desktop”, “tablet”, “mobile”, “smart TV”.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ip_address::String

Returns Optional. The IP address of the device for the given context.

Note: Google Ads does not support IP address matching for end users in the European Economic Area (EEA), United Kingdom (UK), or Switzerland (CH). Add logic to conditionally exclude sharing IP addresses from users from these regions and ensure that you provide users with clear and comprehensive information about the data you collect on your sites, apps, and other properties and get consent where required by law or any applicable Google policies. See the About offline conversion imports page for more details.

Returns:

  • (::String)

    Optional. The IP address of the device for the given context.

    Note: Google Ads does not support IP address matching for end users in the European Economic Area (EEA), United Kingdom (UK), or Switzerland (CH). Add logic to conditionally exclude sharing IP addresses from users from these regions and ensure that you provide users with clear and comprehensive information about the data you collect on your sites, apps, and other properties and get consent where required by law or any applicable Google policies. See the About offline conversion imports page for more details.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#language_code::String

Returns Optional. The language the device uses in ISO 639-1 format.

Returns:

  • (::String)

    Optional. The language the device uses in ISO 639-1 format.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#model::String

Returns Optional. The model of the device.

Returns:

  • (::String)

    Optional. The model of the device.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#operating_system::String

Returns Optional. The operating system or platform of the device.

Returns:

  • (::String)

    Optional. The operating system or platform of the device.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#operating_system_version::String

Returns Optional. The version of the operating system or platform.

Returns:

  • (::String)

    Optional. The version of the operating system or platform.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#screen_height::Integer

Returns Optional. The height of the screen in pixels.

Returns:

  • (::Integer)

    Optional. The height of the screen in pixels.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#screen_width::Integer

Returns Optional. The width of the screen in pixels.

Returns:

  • (::Integer)

    Optional. The width of the screen in pixels.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_agent::String

Returns Optional. The user-agent string of the device for the given context.

Returns:

  • (::String)

    Optional. The user-agent string of the device for the given context.



72
73
74
75
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 72

class DeviceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end