Class: Google::Ads::DataManager::V1::EncryptionInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/encryption_info.rb

Overview

Encryption information for the data being ingested.

Instance Attribute Summary collapse

Instance Attribute Details

#aws_wrapped_key_info::Google::Ads::DataManager::V1::AwsWrappedKeyInfo

Returns Amazon Web Services wrapped key information.

Note: The following fields are mutually exclusive: aws_wrapped_key_info, gcp_wrapped_key_info. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Ads::DataManager::V1::AwsWrappedKeyInfo)

    Amazon Web Services wrapped key information.

    Note: The following fields are mutually exclusive: aws_wrapped_key_info, gcp_wrapped_key_info. If a field in that set is populated, all other fields in the set will automatically be cleared.



35
36
37
38
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 35

class EncryptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gcp_wrapped_key_info::Google::Ads::DataManager::V1::GcpWrappedKeyInfo

Returns Google Cloud Platform wrapped key information.

Note: The following fields are mutually exclusive: gcp_wrapped_key_info, aws_wrapped_key_info. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Ads::DataManager::V1::GcpWrappedKeyInfo)

    Google Cloud Platform wrapped key information.

    Note: The following fields are mutually exclusive: gcp_wrapped_key_info, aws_wrapped_key_info. If a field in that set is populated, all other fields in the set will automatically be cleared.



35
36
37
38
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 35

class EncryptionInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end