Class: Google::Ads::DataManager::V1::ErrorInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::ErrorInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/processing_errors.rb
Overview
Error counts for each type of error.
Instance Attribute Summary collapse
-
#error_counts ⇒ ::Array<::Google::Ads::DataManager::V1::ErrorCount>
A list of errors and counts per error reason.
Instance Attribute Details
#error_counts ⇒ ::Array<::Google::Ads::DataManager::V1::ErrorCount>
Returns A list of errors and counts per error reason. May not be populated in all cases.
29 30 31 32 |
# File 'proto_docs/google/ads/datamanager/v1/processing_errors.rb', line 29 class ErrorInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |