Module: Google::Ads::DataManager::V1::FeatureSet

Defined in:
proto_docs/google/ads/datamanager/v1/partner_link_service.rb

Overview

The set of supported features for a partner link.

Constant Summary collapse

FEATURE_SET_UNSPECIFIED =

Unspecified feature set. If unspecified, the system behavior defaults to FEATURE_SET_AUDIENCE_AND_EVENT_MANAGEMENT.

0
FEATURE_SET_AUDIENCE_AND_EVENT_MANAGEMENT =

Indicates a link used for audience and event management.

1
FEATURE_SET_AD_EVENT_MANAGEMENT =

Indicates a link used for ad event management.

2