Class: Google::Ads::DataManager::V1::GetUserListGlobalLicenseRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb

Overview

Request to get a UserListGlobalLicense resource.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the user list global license.

Returns:

  • (::String)

    Required. The resource name of the user list global license.



61
62
63
64
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 61

class GetUserListGlobalLicenseRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end