Class: Google::Ads::DataManager::V1::IngestAdEventsRequest
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::IngestAdEventsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/ingestion_service.rb
Overview
Request to upload ad events.
Instance Attribute Summary collapse
-
#ad_events ⇒ ::Array<::Google::Ads::DataManager::V1::AdEvent>
Required.
-
#encryption_info ⇒ ::Google::Ads::DataManager::V1::EncryptionInfo
Optional.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#ad_events ⇒ ::Array<::Google::Ads::DataManager::V1::AdEvent>
Returns Required. Required (at least 1). A list of ad events.
176 177 178 179 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 176 class IngestAdEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encryption_info ⇒ ::Google::Ads::DataManager::V1::EncryptionInfo
Returns Optional. Information about encryption keys which are used to encrypt the data.
176 177 178 179 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 176 class IngestAdEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. If true, the request is validated, but not executed.
176 177 178 179 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 176 class IngestAdEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |