Class: Google::Ads::DataManager::V1::IngestAudienceMembersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/ingestion_service.rb

Overview

Request to upload audience members to the provided destinations. Returns an IngestAudienceMembersResponse.

Instance Attribute Summary collapse

Instance Attribute Details

#audience_members::Array<::Google::Ads::DataManager::V1::AudienceMember>

Returns Required. The list of users to send to the specified destinations. At most 10000 AudienceMember resources can be sent in a single request.

Returns:



61
62
63
64
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 61

class IngestAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Optional. Request-level consent to apply to all users in the request. User-level consent overrides request-level consent, and can be specified in each AudienceMember.

Returns:



61
62
63
64
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 61

class IngestAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#destinations::Array<::Google::Ads::DataManager::V1::Destination>

Returns Required. The list of destinations to send the audience members to.

Returns:



61
62
63
64
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 61

class IngestAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#encoding::Google::Ads::DataManager::V1::Encoding

Returns Optional. Required for UserData uploads. The encoding type of the user identifiers. For hashed user identifiers, this is the encoding type of the hashed string. For encrypted hashed user identifiers, this is the encoding type of the outer encrypted string, but not necessarily the inner hashed string, meaning the inner hashed string could be encoded in a different way than the outer encrypted string. For non UserData uploads, this field is ignored.

Returns:

  • (::Google::Ads::DataManager::V1::Encoding)

    Optional. Required for UserData uploads. The encoding type of the user identifiers. For hashed user identifiers, this is the encoding type of the hashed string. For encrypted hashed user identifiers, this is the encoding type of the outer encrypted string, but not necessarily the inner hashed string, meaning the inner hashed string could be encoded in a different way than the outer encrypted string. For non UserData uploads, this field is ignored.



61
62
63
64
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 61

class IngestAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#encryption_info::Google::Ads::DataManager::V1::EncryptionInfo

Returns Optional. Encryption information for UserData uploads. If not set, it's assumed that uploaded identifying information is hashed but not encrypted. For non UserData uploads, this field is ignored.

Returns:



61
62
63
64
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 61

class IngestAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#terms_of_service::Google::Ads::DataManager::V1::TermsOfService

Returns Optional. The terms of service that the user has accepted/rejected.

Returns:



61
62
63
64
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 61

class IngestAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results.

Returns:

  • (::Boolean)

    Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results.



61
62
63
64
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 61

class IngestAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end