Class: Google::Ads::DataManager::V1::IngestEventsRequest
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::IngestEventsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/ingestion_service.rb
Overview
Request to upload audience members to the provided destinations. Returns an IngestEventsResponse.
Instance Attribute Summary collapse
-
#consent ⇒ ::Google::Ads::DataManager::V1::Consent
Optional.
-
#destinations ⇒ ::Array<::Google::Ads::DataManager::V1::Destination>
Required.
-
#encoding ⇒ ::Google::Ads::DataManager::V1::Encoding
Optional.
-
#encryption_info ⇒ ::Google::Ads::DataManager::V1::EncryptionInfo
Optional.
-
#events ⇒ ::Array<::Google::Ads::DataManager::V1::Event>
Required.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#consent ⇒ ::Google::Ads::DataManager::V1::Consent
Returns Optional. Request-level consent to apply to all users in the request. User-level consent overrides request-level consent, and can be specified in each Event.
150 151 152 153 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 150 class IngestEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destinations ⇒ ::Array<::Google::Ads::DataManager::V1::Destination>
Returns Required. The list of destinations to send the events to.
150 151 152 153 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 150 class IngestEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encoding ⇒ ::Google::Ads::DataManager::V1::Encoding
Returns Optional. Required for UserData
uploads. The encoding type of the user identifiers. For hashed user
identifiers, this is the encoding type of the hashed string. For encrypted
hashed user identifiers, this is the encoding type of the outer encrypted
string, but not necessarily the inner hashed string, meaning the inner
hashed string could be encoded in a different way than the outer encrypted
string. For non UserData uploads, this field is ignored.
150 151 152 153 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 150 class IngestEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encryption_info ⇒ ::Google::Ads::DataManager::V1::EncryptionInfo
Returns Optional. Encryption information for
UserData uploads. If not set, it's
assumed that uploaded identifying information is hashed but not encrypted.
For non UserData uploads, this field is ignored.
150 151 152 153 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 150 class IngestEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#events ⇒ ::Array<::Google::Ads::DataManager::V1::Event>
Returns Required. The list of events to send to the specified destinations. At most 2000 Event resources can be sent in a single request.
150 151 152 153 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 150 class IngestEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. For testing purposes. If true, the request is validated but not
executed. Only errors are returned, not results.
150 151 152 153 |
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 150 class IngestEventsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |