Class: Google::Ads::DataManager::V1::IngestionService::Rest::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb

Overview

REST client for the IngestionService service.

Service for sending audience data to supported destinations.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new IngestionService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::DataManager::V1::IngestionService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::DataManager::V1::IngestionService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the IngestionService client.

Yield Parameters:



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 124

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @ingestion_service_stub = ::Google::Ads::DataManager::V1::IngestionService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @ingestion_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the IngestionService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all IngestionService clients
::Google::Ads::DataManager::V1::IngestionService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Ads", "DataManager", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the IngestionService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



94
95
96
97
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 94

def configure
  yield @config if block_given?
  @config
end

#ingest_audience_members(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::IngestAudienceMembersResponse #ingest_audience_members(destinations: nil, audience_members: nil, consent: nil, validate_only: nil, encoding: nil, encryption_info: nil, terms_of_service: nil) ⇒ ::Google::Ads::DataManager::V1::IngestAudienceMembersResponse

Uploads a list of AudienceMember resources to the provided Destination.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::IngestionService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::IngestAudienceMembersRequest.new

# Call the ingest_audience_members method.
result = client.ingest_audience_members request

# The returned object is of type Google::Ads::DataManager::V1::IngestAudienceMembersResponse.
p result

Overloads:

  • #ingest_audience_members(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::IngestAudienceMembersResponse

    Pass arguments to ingest_audience_members via a request object, either of type Google::Ads::DataManager::V1::IngestAudienceMembersRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::IngestAudienceMembersRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #ingest_audience_members(destinations: nil, audience_members: nil, consent: nil, validate_only: nil, encoding: nil, encryption_info: nil, terms_of_service: nil) ⇒ ::Google::Ads::DataManager::V1::IngestAudienceMembersResponse

    Pass arguments to ingest_audience_members via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • destinations (::Array<::Google::Ads::DataManager::V1::Destination, ::Hash>) (defaults to: nil)

      Required. The list of destinations to send the audience members to.

    • audience_members (::Array<::Google::Ads::DataManager::V1::AudienceMember, ::Hash>) (defaults to: nil)

      Required. The list of users to send to the specified destinations. At most 10000 AudienceMember resources can be sent in a single request.

    • consent (::Google::Ads::DataManager::V1::Consent, ::Hash) (defaults to: nil)

      Optional. Request-level consent to apply to all users in the request. User-level consent overrides request-level consent, and can be specified in each AudienceMember.

    • validate_only (::Boolean) (defaults to: nil)

      Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results.

    • encoding (::Google::Ads::DataManager::V1::Encoding) (defaults to: nil)

      Optional. Required for UserData uploads. The encoding type of the user identifiers. For hashed user identifiers, this is the encoding type of the hashed string. For encrypted hashed user identifiers, this is the encoding type of the outer encrypted string, but not necessarily the inner hashed string, meaning the inner hashed string could be encoded in a different way than the outer encrypted string. For non UserData uploads, this field is ignored.

    • encryption_info (::Google::Ads::DataManager::V1::EncryptionInfo, ::Hash) (defaults to: nil)

      Optional. Encryption information for UserData uploads. If not set, it's assumed that uploaded identifying information is hashed but not encrypted. For non UserData uploads, this field is ignored.

    • terms_of_service (::Google::Ads::DataManager::V1::TermsOfService, ::Hash) (defaults to: nil)

      Optional. The terms of service that the user has accepted/rejected.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 248

def ingest_audience_members request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::IngestAudienceMembersRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.ingest_audience_members..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.ingest_audience_members.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.ingest_audience_members.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ingestion_service_stub.ingest_audience_members request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#ingest_events(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::IngestEventsResponse #ingest_events(destinations: nil, events: nil, consent: nil, validate_only: nil, encoding: nil, encryption_info: nil) ⇒ ::Google::Ads::DataManager::V1::IngestEventsResponse

Uploads a list of Event resources from the provided Destination.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::IngestionService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::IngestEventsRequest.new

# Call the ingest_events method.
result = client.ingest_events request

# The returned object is of type Google::Ads::DataManager::V1::IngestEventsResponse.
p result

Overloads:

  • #ingest_events(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::IngestEventsResponse

    Pass arguments to ingest_events via a request object, either of type Google::Ads::DataManager::V1::IngestEventsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::IngestEventsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #ingest_events(destinations: nil, events: nil, consent: nil, validate_only: nil, encoding: nil, encryption_info: nil) ⇒ ::Google::Ads::DataManager::V1::IngestEventsResponse

    Pass arguments to ingest_events via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • destinations (::Array<::Google::Ads::DataManager::V1::Destination, ::Hash>) (defaults to: nil)

      Required. The list of destinations to send the events to.

    • events (::Array<::Google::Ads::DataManager::V1::Event, ::Hash>) (defaults to: nil)

      Required. The list of events to send to the specified destinations. At most 2000 Event resources can be sent in a single request.

    • consent (::Google::Ads::DataManager::V1::Consent, ::Hash) (defaults to: nil)

      Optional. Request-level consent to apply to all users in the request. User-level consent overrides request-level consent, and can be specified in each Event.

    • validate_only (::Boolean) (defaults to: nil)

      Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results.

    • encoding (::Google::Ads::DataManager::V1::Encoding) (defaults to: nil)

      Optional. Required for UserData uploads. The encoding type of the user identifiers. For hashed user identifiers, this is the encoding type of the hashed string. For encrypted hashed user identifiers, this is the encoding type of the outer encrypted string, but not necessarily the inner hashed string, meaning the inner hashed string could be encoded in a different way than the outer encrypted string. For non UserData uploads, this field is ignored.

    • encryption_info (::Google::Ads::DataManager::V1::EncryptionInfo, ::Hash) (defaults to: nil)

      Optional. Encryption information for UserData uploads. If not set, it's assumed that uploaded identifying information is hashed but not encrypted. For non UserData uploads, this field is ignored.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 447

def ingest_events request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::IngestEventsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.ingest_events..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.ingest_events.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.ingest_events.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ingestion_service_stub.ingest_events request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


171
172
173
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 171

def logger
  @ingestion_service_stub.logger
end

#remove_audience_members(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::RemoveAudienceMembersResponse #remove_audience_members(destinations: nil, audience_members: nil, validate_only: nil, encoding: nil, encryption_info: nil) ⇒ ::Google::Ads::DataManager::V1::RemoveAudienceMembersResponse

Removes a list of AudienceMember resources from the provided Destination.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::IngestionService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::RemoveAudienceMembersRequest.new

# Call the remove_audience_members method.
result = client.remove_audience_members request

# The returned object is of type Google::Ads::DataManager::V1::RemoveAudienceMembersResponse.
p result

Overloads:

  • #remove_audience_members(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::RemoveAudienceMembersResponse

    Pass arguments to remove_audience_members via a request object, either of type RemoveAudienceMembersRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::RemoveAudienceMembersRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #remove_audience_members(destinations: nil, audience_members: nil, validate_only: nil, encoding: nil, encryption_info: nil) ⇒ ::Google::Ads::DataManager::V1::RemoveAudienceMembersResponse

    Pass arguments to remove_audience_members via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • destinations (::Array<::Google::Ads::DataManager::V1::Destination, ::Hash>) (defaults to: nil)

      Required. The list of destinations to remove the users from.

    • audience_members (::Array<::Google::Ads::DataManager::V1::AudienceMember, ::Hash>) (defaults to: nil)

      Required. The list of users to remove.

    • validate_only (::Boolean) (defaults to: nil)

      Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results.

    • encoding (::Google::Ads::DataManager::V1::Encoding) (defaults to: nil)

      Optional. Required for UserData uploads. The encoding type of the user identifiers. Applies to only the outer encoding for encrypted user identifiers. For non UserData uploads, this field is ignored.

    • encryption_info (::Google::Ads::DataManager::V1::EncryptionInfo, ::Hash) (defaults to: nil)

      Optional. Encryption information for UserData uploads. If not set, it's assumed that uploaded identifying information is hashed but not encrypted. For non UserData uploads, this field is ignored.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 343

def remove_audience_members request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::RemoveAudienceMembersRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.remove_audience_members..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.remove_audience_members.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.remove_audience_members.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ingestion_service_stub.remove_audience_members request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#retrieve_request_status(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::RetrieveRequestStatusResponse #retrieve_request_status(request_id: nil) ⇒ ::Google::Ads::DataManager::V1::RetrieveRequestStatusResponse

Gets the status of a request given request id.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::IngestionService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::RetrieveRequestStatusRequest.new

# Call the retrieve_request_status method.
result = client.retrieve_request_status request

# The returned object is of type Google::Ads::DataManager::V1::RetrieveRequestStatusResponse.
p result

Overloads:

  • #retrieve_request_status(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::RetrieveRequestStatusResponse

    Pass arguments to retrieve_request_status via a request object, either of type RetrieveRequestStatusRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::RetrieveRequestStatusRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #retrieve_request_status(request_id: nil) ⇒ ::Google::Ads::DataManager::V1::RetrieveRequestStatusResponse

    Pass arguments to retrieve_request_status via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • request_id (::String) (defaults to: nil)

      Required. Required. The request ID of the Data Manager API request.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 525

def retrieve_request_status request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::RetrieveRequestStatusRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.retrieve_request_status..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.retrieve_request_status.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.retrieve_request_status.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @ingestion_service_stub.retrieve_request_status request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


104
105
106
# File 'lib/google/ads/data_manager/v1/ingestion_service/rest/client.rb', line 104

def universe_domain
  @ingestion_service_stub.universe_domain
end