Class: Google::Ads::DataManager::V1::IpData

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/audience.rb

Overview

IP address information for a user. We recommend including observe_start_time and observe_end_time to help improve Customer Match match rates.

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address::String

Returns Required. IP address captured at the time of customer interaction. Accepts standard string formats for both IPv4 and IPv6.

Returns:

  • (::String)

    Required. IP address captured at the time of customer interaction. Accepts standard string formats for both IPv4 and IPv6.



151
152
153
154
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 151

class IpData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#observe_end_time::Google::Protobuf::Timestamp

Returns Optional. Last recorded interaction time from this IP address in a session.

Returns:



151
152
153
154
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 151

class IpData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#observe_start_time::Google::Protobuf::Timestamp

Returns Optional. First recorded interaction time from this IP address in a session.

Returns:



151
152
153
154
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 151

class IpData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end