Class: Google::Ads::DataManager::V1::Item

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/cart_data.rb

Overview

Represents an item in the cart associated with the event.

Instance Attribute Summary collapse

Instance Attribute Details

#additional_item_parameters::Array<::Google::Ads::DataManager::V1::ItemParameter>

Returns Optional. A bucket of any event parameters related to an item to be included within the event that were not already specified using other structured fields.

Returns:



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#conversion_value::Float

Returns Optional. The conversion value associated with this item within the event, for cases where the conversion value is different for each item.

Returns:

  • (::Float)

    Optional. The conversion value associated with this item within the event, for cases where the conversion value is different for each item.



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#custom_variables::Array<::Google::Ads::DataManager::V1::ItemCustomVariable>

Returns Optional. Additional key/value pair information to send to the conversion containers (conversion action or Floodlight activity), when tracking per-item conversions.

Returns:



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#item_id::String

Returns Optional. A unique identifier to reference the item.

Returns:

  • (::String)

    Optional. A unique identifier to reference the item.



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#merchant_feed_label::String

Returns Optional. The feed label of the Merchant Center feed. If countries are still being used, the 2-letter country code in ISO-3166-1 alpha-2 can be used instead. For Store Sales events this will override the value set at the cart level. This field is ignored for other events.

Returns:

  • (::String)

    Optional. The feed label of the Merchant Center feed. If countries are still being used, the 2-letter country code in ISO-3166-1 alpha-2 can be used instead. For Store Sales events this will override the value set at the cart level. This field is ignored for other events.



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#merchant_feed_language_code::String

Returns Optional. The language code in ISO 639-1 associated with the Merchant Center feed where your items are uploaded.

Returns:

  • (::String)

    Optional. The language code in ISO 639-1 associated with the Merchant Center feed where your items are uploaded.



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#merchant_id::String

Returns Optional. The Merchant Center ID associated with the item. For Store Sales events this will override the value set at the cart level. This field is ignored for other events.

Returns:

  • (::String)

    Optional. The Merchant Center ID associated with the item. For Store Sales events this will override the value set at the cart level. This field is ignored for other events.



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#merchant_product_id::String

Returns Optional. The product ID within the Merchant Center account.

Returns:

  • (::String)

    Optional. The product ID within the Merchant Center account.



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#quantity::Integer

Returns Optional. The number of this item associated with the event.

Returns:

  • (::Integer)

    Optional. The number of this item associated with the event.



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unit_price::Float

Returns Optional. The unit price excluding tax, shipping, and any transaction level discounts.

Returns:

  • (::Float)

    Optional. The unit price excluding tax, shipping, and any transaction level discounts.



99
100
101
102
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 99

class Item
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end