Class: Google::Ads::DataManager::V1::ItemCustomVariable
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::ItemCustomVariable
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/cart_data.rb
Overview
Item-level custom variable for ads conversions.
Instance Attribute Summary collapse
-
#destination_references ⇒ ::Array<::String>
Optional.
-
#value ⇒ ::String
Optional.
-
#variable ⇒ ::String
Optional.
Instance Attribute Details
#destination_references ⇒ ::Array<::String>
Returns Optional. Reference string used to determine which of the Event.destination_references the custom variable should be sent to. If empty, the Event.destination_references will be used.
119 120 121 122 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 119 class ItemCustomVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#value ⇒ ::String
Returns Optional. The value to store for the custom variable.
119 120 121 122 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 119 class ItemCustomVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variable ⇒ ::String
Returns Optional. The name of the custom variable to set. If the variable is not found for the given destination, it will be ignored.
119 120 121 122 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 119 class ItemCustomVariable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |