Class: Google::Ads::DataManager::V1::ItemParameter

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/item_parameter.rb

Overview

A bucket of any event parameters related to an item to be included within the event that were not already specified using other structured fields.

Instance Attribute Summary collapse

Instance Attribute Details

#parameter_name::String

Returns Required. The name of the parameter to use.

Returns:

  • (::String)

    Required. The name of the parameter to use.



34
35
36
37
# File 'proto_docs/google/ads/datamanager/v1/item_parameter.rb', line 34

class ItemParameter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::String

Returns Required. The string representation of the value of the parameter to set.

Returns:

  • (::String)

    Required. The string representation of the value of the parameter to set.



34
35
36
37
# File 'proto_docs/google/ads/datamanager/v1/item_parameter.rb', line 34

class ItemParameter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end