Class: Google::Ads::DataManager::V1::ListUserListDirectLicensesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_direct_license_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



127
128
129
130
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license_service.rb', line 127

class ListUserListDirectLicensesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_list_direct_licenses::Array<::Google::Ads::DataManager::V1::UserListDirectLicense>

Returns The licenses for the given user list in the request.

Returns:



127
128
129
130
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license_service.rb', line 127

class ListUserListDirectLicensesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end