Class: Google::Ads::DataManager::V1::ListUserListGlobalLicenseCustomerInfosResponse
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::ListUserListGlobalLicenseCustomerInfosResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb
Overview
Response from the [ListUserListGlobalLicensesCustomerInfoRequest][google.ads.datamanager.v1.ListUserListGlobalLicensesCustomerInfoRequest].
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#user_list_global_license_customer_infos ⇒ ::Array<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo>
The customer information for the given license in the request.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
197 198 199 200 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 197 class ListUserListGlobalLicenseCustomerInfosResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_list_global_license_customer_infos ⇒ ::Array<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo>
Returns The customer information for the given license in the request.
197 198 199 200 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 197 class ListUserListGlobalLicenseCustomerInfosResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |