Class: Google::Ads::DataManager::V1::ListUserListGlobalLicensesResponse
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::ListUserListGlobalLicensesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb
Overview
Response from the ListUserListGlobalLicensesRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#user_list_global_licenses ⇒ ::Array<::Google::Ads::DataManager::V1::UserListGlobalLicense>
The licenses for the given user list in the request.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
127 128 129 130 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 127 class ListUserListGlobalLicensesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_list_global_licenses ⇒ ::Array<::Google::Ads::DataManager::V1::UserListGlobalLicense>
Returns The licenses for the given user list in the request.
127 128 129 130 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 127 class ListUserListGlobalLicensesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |