Class: Google::Ads::DataManager::V1::ListUserListsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_service.rb

Overview

Request message for ListUserLists.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. A filter string. All fields need to be on the left hand side of each condition (for example: display_name = "list 1"). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case.

Supported operations:

  • AND
  • =
  • !=
  • >
  • >=
  • <
  • <=
  • : (has)

Supported fields:

  • id
  • display_name
  • description
  • membership_status
  • integration_code
  • access_reason
  • ingested_user_list_info.upload_key_types.

Returns:

  • (::String)

    Optional. A filter string. All fields need to be on the left hand side of each condition (for example: display_name = "list 1"). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case.

    Supported operations:

    • AND
    • =
    • !=
    • >
    • >=
    • <
    • <=
    • : (has)

    Supported fields:

    • id
    • display_name
    • description
    • membership_status
    • integration_code
    • access_reason
    • ingested_user_list_info.upload_key_types


82
83
84
85
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 82

class ListUserListsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of user lists to return. The service may return fewer than this value. If unspecified, at most 50 user lists will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of user lists to return. The service may return fewer than this value. If unspecified, at most 50 user lists will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



82
83
84
85
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 82

class ListUserListsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListUserLists call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListUserLists must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListUserLists call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListUserLists must match the call that provided the page token.



82
83
84
85
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 82

class ListUserListsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent account which owns this collection of user lists. Format: accountTypes/{account_type}/accounts/{account}.

Returns:

  • (::String)

    Required. The parent account which owns this collection of user lists. Format: accountTypes/{account_type}/accounts/{account}



82
83
84
85
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 82

class ListUserListsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end