Class: Google::Ads::DataManager::V1::ListUserListsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_service.rb

Overview

Response message for ListUserLists.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



95
96
97
98
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 95

class ListUserListsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_lists::Array<::Google::Ads::DataManager::V1::UserList>

Returns The user lists from the specified account.

Returns:



95
96
97
98
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 95

class ListUserListsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end