Class: Google::Ads::DataManager::V1::MarketingDataInsightsService::Rest::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/google/ads/data_manager/v1/marketing_data_insights_service/rest/client.rb

Overview

REST client for the MarketingDataInsightsService service.

Service to return insights on marketing data.

This feature is only available to data partners.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new MarketingDataInsightsService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::DataManager::V1::MarketingDataInsightsService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::DataManager::V1::MarketingDataInsightsService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the MarketingDataInsightsService client.

Yield Parameters:



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/google/ads/data_manager/v1/marketing_data_insights_service/rest/client.rb', line 126

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @marketing_data_insights_service_stub = ::Google::Ads::DataManager::V1::MarketingDataInsightsService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @marketing_data_insights_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the MarketingDataInsightsService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all MarketingDataInsightsService clients
::Google::Ads::DataManager::V1::MarketingDataInsightsService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/google/ads/data_manager/v1/marketing_data_insights_service/rest/client.rb', line 64

def self.configure
  @configure ||= begin
    namespace = ["Google", "Ads", "DataManager", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the MarketingDataInsightsService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



96
97
98
99
# File 'lib/google/ads/data_manager/v1/marketing_data_insights_service/rest/client.rb', line 96

def configure
  yield @config if block_given?
  @config
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


173
174
175
# File 'lib/google/ads/data_manager/v1/marketing_data_insights_service/rest/client.rb', line 173

def logger
  @marketing_data_insights_service_stub.logger
end

#retrieve_insights(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::RetrieveInsightsResponse #retrieve_insights(parent: nil, baseline: nil, user_list_id: nil) ⇒ ::Google::Ads::DataManager::V1::RetrieveInsightsResponse

Retrieves marketing data insights for a given user list.

This feature is only available to data partners.

Authorization Headers:

This method supports the following optional headers to define how the API authorizes access for the request:

  • login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/{loginAccountType}/accounts/{loginAccountId}
  • linked-account: (Optional) The resource name of the account with an established product link to the login-account. Format: accountTypes/{linkedAccountType}/accounts/{linkedAccountId}

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::MarketingDataInsightsService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::RetrieveInsightsRequest.new

# Call the retrieve_insights method.
result = client.retrieve_insights request

# The returned object is of type Google::Ads::DataManager::V1::RetrieveInsightsResponse.
p result

Overloads:

  • #retrieve_insights(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::RetrieveInsightsResponse

    Pass arguments to retrieve_insights via a request object, either of type RetrieveInsightsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::RetrieveInsightsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #retrieve_insights(parent: nil, baseline: nil, user_list_id: nil) ⇒ ::Google::Ads::DataManager::V1::RetrieveInsightsResponse

    Pass arguments to retrieve_insights via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent account that owns the user list. Format: accountTypes/{account_type}/accounts/{account}

    • baseline (::Google::Ads::DataManager::V1::Baseline, ::Hash) (defaults to: nil)

      Required. Baseline for the insights requested.

    • user_list_id (::String) (defaults to: nil)

      Required. The user list ID for which insights are requested.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/google/ads/data_manager/v1/marketing_data_insights_service/rest/client.rb', line 242

def retrieve_insights request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::RetrieveInsightsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.retrieve_insights..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.retrieve_insights.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.retrieve_insights.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @marketing_data_insights_service_stub.retrieve_insights request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


106
107
108
# File 'lib/google/ads/data_manager/v1/marketing_data_insights_service/rest/client.rb', line 106

def universe_domain
  @marketing_data_insights_service_stub.universe_domain
end