Class: Google::Ads::DataManager::V1::MobileIdInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list.rb

Overview

Additional information when MOBILE_ID is one of the upload_key_types.

Defined Under Namespace

Modules: KeySpace

Instance Attribute Summary collapse

Instance Attribute Details

#app_id::String

Returns Required. Immutable. A string that uniquely identifies a mobile application from which the data was collected.

Returns:

  • (::String)

    Required. Immutable. A string that uniquely identifies a mobile application from which the data was collected.



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 255

class MobileIdInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Key space for mobile ID.
  module KeySpace
    # Not specified.
    KEY_SPACE_UNSPECIFIED = 0

    # The iOS keyspace.
    IOS = 1

    # The Android keyspace.
    ANDROID = 2
  end
end

#data_source_type::Google::Ads::DataManager::V1::DataSourceType

Returns Optional. Immutable. Source of the upload data.

Returns:



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 255

class MobileIdInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Key space for mobile ID.
  module KeySpace
    # Not specified.
    KEY_SPACE_UNSPECIFIED = 0

    # The iOS keyspace.
    IOS = 1

    # The Android keyspace.
    ANDROID = 2
  end
end

#key_space::Google::Ads::DataManager::V1::MobileIdInfo::KeySpace

Returns Required. Immutable. The key space of mobile IDs.

Returns:



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 255

class MobileIdInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Key space for mobile ID.
  module KeySpace
    # Not specified.
    KEY_SPACE_UNSPECIFIED = 0

    # The iOS keyspace.
    IOS = 1

    # The Android keyspace.
    ANDROID = 2
  end
end