Class: Google::Ads::DataManager::V1::PairData

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/audience.rb

Overview

PAIR IDs for the audience. At least one PAIR ID is required.

This feature is only available to data partners.

Instance Attribute Summary collapse

Instance Attribute Details

#pair_ids::Array<::String>

Returns Required. Cleanroom-provided PII data, hashed with SHA256, and encrypted with an EC commutative cipher using publisher key for the PAIR user list. At most 10 pairIds can be provided in a single AudienceMember.

Returns:

  • (::Array<::String>)

    Required. Cleanroom-provided PII data, hashed with SHA256, and encrypted with an EC commutative cipher using publisher key for the PAIR user list. At most 10 pairIds can be provided in a single AudienceMember.



80
81
82
83
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 80

class PairData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end