Class: Google::Ads::DataManager::V1::PartnerLinkService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/ads/data_manager/v1/partner_link_service/client.rb

Overview

Client for the PartnerLinkService service.

Service for managing partner links.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#account_path, #partner_link_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new PartnerLinkService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::DataManager::V1::PartnerLinkService::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::DataManager::V1::PartnerLinkService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the PartnerLinkService client.

Yield Parameters:



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 124

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/ads/datamanager/v1/partner_link_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @partner_link_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Ads::DataManager::V1::PartnerLinkService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @partner_link_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the PartnerLinkService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all PartnerLinkService clients
::Google::Ads::DataManager::V1::PartnerLinkService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Ads", "DataManager", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the PartnerLinkService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



94
95
96
97
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 94

def configure
  yield @config if block_given?
  @config
end

Creates a partner link for the given account.

Authorization Headers:

This method supports the following optional headers to define how the API authorizes access for the request:

  • login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/{loginAccountType}/accounts/{loginAccountId}

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::PartnerLinkService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::CreatePartnerLinkRequest.new

# Call the create_partner_link method.
result = client.create_partner_link request

# The returned object is of type Google::Ads::DataManager::V1::PartnerLink.
p result

Overloads:

  • #create_partner_link(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::PartnerLink

    Pass arguments to create_partner_link via a request object, either of type CreatePartnerLinkRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::CreatePartnerLinkRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_partner_link(parent: nil, partner_link: nil) ⇒ ::Google::Ads::DataManager::V1::PartnerLink

    Pass arguments to create_partner_link via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of partner links. Format: accountTypes/{account_type}/accounts/{account}

    • partner_link (::Google::Ads::DataManager::V1::PartnerLink, ::Hash) (defaults to: nil)

      Required. The partner link to create.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 243

def create_partner_link request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::CreatePartnerLinkRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_partner_link..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_partner_link.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_partner_link.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @partner_link_service_stub.call_rpc :create_partner_link, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

Deletes a partner link for the given account.

Authorization Headers:

This method supports the following optional headers to define how the API authorizes access for the request:

  • login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/{loginAccountType}/accounts/{loginAccountId}

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::PartnerLinkService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::DeletePartnerLinkRequest.new

# Call the delete_partner_link method.
result = client.delete_partner_link request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_partner_link(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_partner_link via a request object, either of type DeletePartnerLinkRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::DeletePartnerLinkRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_partner_link(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_partner_link via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the partner link to delete. Format: accountTypes/{account_type}/accounts/{account}/partnerLinks/{partner_link}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 340

def delete_partner_link request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::DeletePartnerLinkRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_partner_link..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_partner_link.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_partner_link.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @partner_link_service_stub.call_rpc :delete_partner_link, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


180
181
182
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 180

def logger
  @partner_link_service_stub.logger
end

Searches for all partner links to and from a given account.

Authorization Headers:

This method supports the following optional headers to define how the API authorizes access for the request:

  • login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format: accountTypes/{loginAccountType}/accounts/{loginAccountId}

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::PartnerLinkService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::SearchPartnerLinksRequest.new

# Call the search_partner_links method.
result = client.search_partner_links request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Ads::DataManager::V1::PartnerLink.
  p item
end

Overloads:

  • #search_partner_links(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::PartnerLink>

    Pass arguments to search_partner_links via a request object, either of type SearchPartnerLinksRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::SearchPartnerLinksRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #search_partner_links(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::PartnerLink>

    Pass arguments to search_partner_links via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Account to search for partner links. If no filter is specified, all partner links where this account is either the owning_account or partner_account are returned.

      Format: accountTypes/{account_type}/accounts/{account}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of partner links to return. The service may return fewer than this value. If unspecified, at most 10 partner links will be returned. The maximum value is 100; values above 100 will be coerced to 100.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous SearchPartnerLinks call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to SearchPartnerLinks must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      Optional. A filter string. All fields need to be on the left hand side of each condition (for example: partner_link_id = 123456789). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case.

      Supported operations:

      • AND
      • =
      • !=

      Supported fields:

      • partner_link_id
      • owning_account.account_type
      • owning_account.account_id
      • partner_account.account_type
      • partner_account.account_id

      Example: owning_account.account_type = "GOOGLE_ADS" AND partner_account.account_id = 987654321

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 479

def search_partner_links request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::SearchPartnerLinksRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.search_partner_links..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.search_partner_links.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.search_partner_links.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @partner_link_service_stub.call_rpc :search_partner_links, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @partner_link_service_stub, :search_partner_links, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


104
105
106
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 104

def universe_domain
  @partner_link_service_stub.universe_domain
end