Class: Google::Ads::DataManager::V1::PpidData

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/audience.rb

Overview

Publisher provided identifiers data holding the ppids. At least one ppid is required.

This feature is only available to data partners.

Instance Attribute Summary collapse

Instance Attribute Details

#ppids::Array<::String>

Returns Required. The list of publisher provided identifiers for a user.

Returns:

  • (::Array<::String>)

    Required. The list of publisher provided identifiers for a user.



113
114
115
116
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 113

class PpidData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end