Module: Google::Ads::DataManager::V1::ProcessingErrorReason

Defined in:
proto_docs/google/ads/datamanager/v1/processing_errors.rb

Overview

The processing error reason.

Constant Summary collapse

PROCESSING_ERROR_REASON_UNSPECIFIED =

The processing error reason is unknown.

0
PROCESSING_ERROR_REASON_INVALID_CUSTOM_VARIABLE =

The custom variable is invalid.

1
PROCESSING_ERROR_REASON_CUSTOM_VARIABLE_NOT_ENABLED =

The status of the custom variable is not enabled.

2
PROCESSING_ERROR_REASON_EVENT_TOO_OLD =

The conversion is older than max supported age.

3
4
5
6
PROCESSING_ERROR_REASON_DUPLICATE_GCLID =

A conversion with the same GCLID and conversion time already exists in the system.

7
PROCESSING_ERROR_REASON_DUPLICATE_TRANSACTION_ID =

A conversion with the same order id and conversion action combination was already uploaded.

8
PROCESSING_ERROR_REASON_INVALID_GBRAID =

The gbraid could not be decoded.

9
PROCESSING_ERROR_REASON_INVALID_GCLID =

The google click ID could not be decoded.

10
PROCESSING_ERROR_REASON_INVALID_MERCHANT_ID =

Merchant id contains non-digit characters.

11
PROCESSING_ERROR_REASON_INVALID_WBRAID =

The wbraid could not be decoded.

12
PROCESSING_ERROR_REASON_INTERNAL_ERROR =

Internal error.

13
PROCESSING_ERROR_REASON_DESTINATION_ACCOUNT_ENHANCED_CONVERSIONS_TERMS_NOT_SIGNED =

Enhanced conversions terms are not signed in the destination account.

14
PROCESSING_ERROR_REASON_INVALID_EVENT =

The event is invalid.

15
PROCESSING_ERROR_REASON_INSUFFICIENT_MATCHED_TRANSACTIONS =

The matched transactions are less than the minimum threshold.

16
PROCESSING_ERROR_REASON_INSUFFICIENT_TRANSACTIONS =

The transactions are less than the minimum threshold.

17
PROCESSING_ERROR_REASON_INVALID_FORMAT =

The event has format error.

18
PROCESSING_ERROR_REASON_DECRYPTION_ERROR =

The event has a decryption error.

19
PROCESSING_ERROR_REASON_DEK_DECRYPTION_ERROR =

The DEK failed to be decrypted.

20
PROCESSING_ERROR_REASON_INVALID_WIP =

The WIP is formatted incorrectly or the WIP does not exist.

21
PROCESSING_ERROR_REASON_INVALID_KEK =

The KEK cannot decrypt data because it is the wrong KEK, or it does not exist.

22
PROCESSING_ERROR_REASON_WIP_AUTH_FAILED =

The WIP could not be used because it was rejected by its attestation condition.

23
PROCESSING_ERROR_REASON_KEK_PERMISSION_DENIED =

The system did not have the permissions needed to access the KEK.

24
PROCESSING_ERROR_REASON_AWS_AUTH_FAILED =

The system failed to authenticate with AWS.

27
PROCESSING_ERROR_REASON_USER_IDENTIFIER_DECRYPTION_ERROR =

Failed to decrypt the UserIdentifier data using the DEK.

25
PROCESSING_ERROR_OPERATING_ACCOUNT_MISMATCH_FOR_AD_IDENTIFIER =

The user attempted to ingest events with an ad identifier that isn't from the operating account's ads.

26