Class: Google::Ads::DataManager::V1::ProductAccount
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::ProductAccount
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/destination.rb
Overview
Represents a specific account.
Defined Under Namespace
Modules: AccountType
Instance Attribute Summary collapse
-
#account_id ⇒ ::String
Required.
-
#account_type ⇒ ::Google::Ads::DataManager::V1::ProductAccount::AccountType
Optional.
-
#product ⇒ ::Google::Ads::DataManager::V1::Product
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#account_id ⇒ ::String
Returns Required. The ID of the account. For example, your Google Ads account ID.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/ads/datamanager/v1/destination.rb', line 77 class ProductAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents Google account types. Used to locate accounts and # destinations. module AccountType # Unspecified product. Should never be used. ACCOUNT_TYPE_UNSPECIFIED = 0 # Google Ads. GOOGLE_ADS = 1 # Display & Video 360 partner. DISPLAY_VIDEO_PARTNER = 2 # Display & Video 360 advertiser. DISPLAY_VIDEO_ADVERTISER = 3 # Data Partner. DATA_PARTNER = 4 # Google Analytics. GOOGLE_ANALYTICS_PROPERTY = 5 # Google Ad Manager audience link. GOOGLE_AD_MANAGER_AUDIENCE_LINK = 6 end end |
#account_type ⇒ ::Google::Ads::DataManager::V1::ProductAccount::AccountType
Returns Optional. The type of the account. For example, GOOGLE_ADS.
Either account_type or the deprecated product is required.
If both are set, the values must match.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/ads/datamanager/v1/destination.rb', line 77 class ProductAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents Google account types. Used to locate accounts and # destinations. module AccountType # Unspecified product. Should never be used. ACCOUNT_TYPE_UNSPECIFIED = 0 # Google Ads. GOOGLE_ADS = 1 # Display & Video 360 partner. DISPLAY_VIDEO_PARTNER = 2 # Display & Video 360 advertiser. DISPLAY_VIDEO_ADVERTISER = 3 # Data Partner. DATA_PARTNER = 4 # Google Analytics. GOOGLE_ANALYTICS_PROPERTY = 5 # Google Ad Manager audience link. GOOGLE_AD_MANAGER_AUDIENCE_LINK = 6 end end |
#product ⇒ ::Google::Ads::DataManager::V1::Product
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Deprecated. Use
account_type
instead.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'proto_docs/google/ads/datamanager/v1/destination.rb', line 77 class ProductAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents Google account types. Used to locate accounts and # destinations. module AccountType # Unspecified product. Should never be used. ACCOUNT_TYPE_UNSPECIFIED = 0 # Google Ads. GOOGLE_ADS = 1 # Display & Video 360 partner. DISPLAY_VIDEO_PARTNER = 2 # Display & Video 360 advertiser. DISPLAY_VIDEO_ADVERTISER = 3 # Data Partner. DATA_PARTNER = 4 # Google Analytics. GOOGLE_ANALYTICS_PROPERTY = 5 # Google Ad Manager audience link. GOOGLE_AD_MANAGER_AUDIENCE_LINK = 6 end end |