Class: Google::Ads::DataManager::V1::RemoveAudienceMembersRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/ingestion_service.rb

Overview

Request to remove users from an audience in the provided destinations. Returns a RemoveAudienceMembersResponse.

Instance Attribute Summary collapse

Instance Attribute Details

#audience_members::Array<::Google::Ads::DataManager::V1::AudienceMember>

Returns Required. The list of users to remove.

Returns:



101
102
103
104
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 101

class RemoveAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#destinations::Array<::Google::Ads::DataManager::V1::Destination>

Returns Required. The list of destinations to remove the users from.

Returns:



101
102
103
104
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 101

class RemoveAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#encoding::Google::Ads::DataManager::V1::Encoding

Returns Optional. Required for UserData uploads. The encoding type of the user identifiers. Applies to only the outer encoding for encrypted user identifiers. For non UserData uploads, this field is ignored.

Returns:

  • (::Google::Ads::DataManager::V1::Encoding)

    Optional. Required for UserData uploads. The encoding type of the user identifiers. Applies to only the outer encoding for encrypted user identifiers. For non UserData uploads, this field is ignored.



101
102
103
104
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 101

class RemoveAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#encryption_info::Google::Ads::DataManager::V1::EncryptionInfo

Returns Optional. Encryption information for UserData uploads. If not set, it's assumed that uploaded identifying information is hashed but not encrypted. For non UserData uploads, this field is ignored.

Returns:



101
102
103
104
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 101

class RemoveAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results.

Returns:

  • (::Boolean)

    Optional. For testing purposes. If true, the request is validated but not executed. Only errors are returned, not results.



101
102
103
104
# File 'proto_docs/google/ads/datamanager/v1/ingestion_service.rb', line 101

class RemoveAudienceMembersRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end