Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestAudienceMembersStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb

Overview

The status of the ingest audience members request.

Instance Attribute Summary collapse

Instance Attribute Details

#mobile_data_ingestion_status::Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestMobileDataStatus

Returns The status of the mobile data ingestion to the destination.

Note: The following fields are mutually exclusive: mobile_data_ingestion_status, user_data_ingestion_status, pair_data_ingestion_status. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



74
75
76
77
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 74

class IngestAudienceMembersStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pair_data_ingestion_status::Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestPairDataStatus

Returns The status of the pair data ingestion to the destination.

Note: The following fields are mutually exclusive: pair_data_ingestion_status, user_data_ingestion_status, mobile_data_ingestion_status. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



74
75
76
77
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 74

class IngestAudienceMembersStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_data_ingestion_status::Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestUserDataStatus

Returns The status of the user data ingestion to the destination.

Note: The following fields are mutually exclusive: user_data_ingestion_status, mobile_data_ingestion_status, pair_data_ingestion_status. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



74
75
76
77
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 74

class IngestAudienceMembersStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end