Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestCompositeDataStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestCompositeDataStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the composite data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#data_type_counts ⇒ ::Array<::Google::Ads::DataManager::V1::RequestStatusPerDestination::DataTypeCount>
The total count of data types sent in the upload request for the destination, broken down by data type.
-
#record_count ⇒ ::Integer
The total count of audience members sent in the upload request for the destination.
-
#upload_match_rate_range ⇒ ::Google::Ads::DataManager::V1::MatchRateRange
The match rate range of the upload.
Instance Attribute Details
#data_type_counts ⇒ ::Array<::Google::Ads::DataManager::V1::RequestStatusPerDestination::DataTypeCount>
Returns The total count of data types sent in the upload request for the destination, broken down by data type. Includes all data types in the request, regardless of whether they were successfully ingested or not.
337 338 339 340 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 337 class IngestCompositeDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#record_count ⇒ ::Integer
Returns The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not.
337 338 339 340 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 337 class IngestCompositeDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#upload_match_rate_range ⇒ ::Google::Ads::DataManager::V1::MatchRateRange
Returns The match rate range of the upload.
337 338 339 340 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 337 class IngestCompositeDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |