Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestMobileDataStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb

Overview

The status of the mobile data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Attribute Details

#mobile_id_count::Integer

Returns The total count of mobile ids sent in the upload request for the destination. Includes all mobile ids in the request, regardless of whether they were successfully ingested or not.

Returns:

  • (::Integer)

    The total count of mobile ids sent in the upload request for the destination. Includes all mobile ids in the request, regardless of whether they were successfully ingested or not.



159
160
161
162
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 159

class IngestMobileDataStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#record_count::Integer

Returns The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not.

Returns:

  • (::Integer)

    The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not.



159
160
161
162
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 159

class IngestMobileDataStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end