Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestUserDataStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb

Overview

The status of the user data ingestion to the destination containing stats related to the ingestion.

Instance Attribute Summary collapse

Instance Attribute Details

#record_count::Integer

Returns The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not.

Returns:

  • (::Integer)

    The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not.



126
127
128
129
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 126

class IngestUserDataStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#upload_match_rate_range::Google::Ads::DataManager::V1::MatchRateRange

Returns The match rate range of the upload.

Returns:



126
127
128
129
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 126

class IngestUserDataStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_identifier_count::Integer

Returns The total count of user identifiers sent in the upload request for the destination. Includes all user identifiers in the request, regardless of whether they were successfully ingested or not.

Returns:

  • (::Integer)

    The total count of user identifiers sent in the upload request for the destination. Includes all user identifiers in the request, regardless of whether they were successfully ingested or not.



126
127
128
129
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 126

class IngestUserDataStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end