Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestUserIdDataStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestUserIdDataStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the user id data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#record_count ⇒ ::Integer
The total count of audience members sent in the upload request for the destination.
-
#user_id_count ⇒ ::Integer
The total count of user ids sent in the upload request for the destination.
Instance Attribute Details
#record_count ⇒ ::Integer
Returns The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not.
257 258 259 260 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 257 class IngestUserIdDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_id_count ⇒ ::Integer
Returns The total count of user ids sent in the upload request for the destination. Includes all user ids in the request, regardless of whether they were successfully ingested or not.
257 258 259 260 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 257 class IngestUserIdDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |