Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveUserDataStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveUserDataStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the user data removal from the destination.
Instance Attribute Summary collapse
-
#record_count ⇒ ::Integer
The total count of audience members sent in the removal request.
-
#user_identifier_count ⇒ ::Integer
The total count of user identifiers sent in the removal request.
Instance Attribute Details
#record_count ⇒ ::Integer
142 143 144 145 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 142 class RemoveUserDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_identifier_count ⇒ ::Integer
142 143 144 145 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 142 class RemoveUserDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |