Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveUserIdDataStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveUserIdDataStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the user id data removal from the destination.
Instance Attribute Summary collapse
-
#record_count ⇒ ::Integer
The total count of audience members sent in the removal request.
-
#user_id_count ⇒ ::Integer
The total count of user ids sent in the removal request.
Instance Attribute Details
#record_count ⇒ ::Integer
Returns The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not.
273 274 275 276 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 273 class RemoveUserIdDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_id_count ⇒ ::Integer
Returns The total count of user ids sent in the removal request. Includes all user ids in the request, regardless of whether they were successfully removed or not.
273 274 275 276 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 273 class RemoveUserIdDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |