Module: Google::Ads::DataManager::V1::RequestStatusPerDestination::RequestStatus

Defined in:
proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb

Overview

The request status.

Constant Summary collapse

REQUEST_STATUS_UNKNOWN =

The request status is unknown.

0
SUCCESS =

Processing succeeded for all records without any errors. However, there may be warnings in the warning_info field.

1
PROCESSING =

The request is processing.

2
FAILED =

Processing failed for all records. Check the error_info field for error details, and check the warning_info field for warning details.

3
PARTIAL_SUCCESS =

Processing completed successfully without errors for some records, but failed with errors for other records. Check the error_info field for error details, and check the warning_info field for warning details.

4