Class: Google::Ads::DataManager::V1::RetrieveInsightsResponse::MarketingDataInsight

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/insights_service.rb

Overview

Insights for marketing data.

This feature is only available to data partners.

Defined Under Namespace

Modules: AudienceInsightsDimension Classes: MarketingDataInsightsAttribute

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Array<::Google::Ads::DataManager::V1::RetrieveInsightsResponse::MarketingDataInsight::MarketingDataInsightsAttribute>

Returns Insights for values of a given dimension.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/ads/datamanager/v1/insights_service.rb', line 85

class MarketingDataInsight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Insights for a collection of related attributes of the same dimension.
  # @!attribute [rw] user_interest_id
  #   @return [::Integer]
  #     The user interest ID.
  # @!attribute [rw] lift
  #   @return [::Float]
  #     Measure of lift that the audience has for the attribute value as
  #     compared to the baseline. Range [0-1].
  # @!attribute [rw] age_range
  #   @return [::Google::Ads::DataManager::V1::AgeRange]
  #     Age range of the audience for which the lift is provided.
  # @!attribute [rw] gender
  #   @return [::Google::Ads::DataManager::V1::Gender]
  #     Gender of the audience for which the lift is provided.
  class MarketingDataInsightsAttribute
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible dimensions for use in generating insights.
  module AudienceInsightsDimension
    # Not specified.
    AUDIENCE_INSIGHTS_DIMENSION_UNSPECIFIED = 0

    # The value is unknown in this version.
    AUDIENCE_INSIGHTS_DIMENSION_UNKNOWN = 1

    # An Affinity UserInterest.
    AFFINITY_USER_INTEREST = 2

    # An In-Market UserInterest.
    IN_MARKET_USER_INTEREST = 3

    # An age range.
    AGE_RANGE = 4

    # A gender.
    GENDER = 5
  end
end

#dimension::Google::Ads::DataManager::V1::RetrieveInsightsResponse::MarketingDataInsight::AudienceInsightsDimension

Returns The dimension to which the insight belongs.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'proto_docs/google/ads/datamanager/v1/insights_service.rb', line 85

class MarketingDataInsight
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Insights for a collection of related attributes of the same dimension.
  # @!attribute [rw] user_interest_id
  #   @return [::Integer]
  #     The user interest ID.
  # @!attribute [rw] lift
  #   @return [::Float]
  #     Measure of lift that the audience has for the attribute value as
  #     compared to the baseline. Range [0-1].
  # @!attribute [rw] age_range
  #   @return [::Google::Ads::DataManager::V1::AgeRange]
  #     Age range of the audience for which the lift is provided.
  # @!attribute [rw] gender
  #   @return [::Google::Ads::DataManager::V1::Gender]
  #     Gender of the audience for which the lift is provided.
  class MarketingDataInsightsAttribute
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible dimensions for use in generating insights.
  module AudienceInsightsDimension
    # Not specified.
    AUDIENCE_INSIGHTS_DIMENSION_UNSPECIFIED = 0

    # The value is unknown in this version.
    AUDIENCE_INSIGHTS_DIMENSION_UNKNOWN = 1

    # An Affinity UserInterest.
    AFFINITY_USER_INTEREST = 2

    # An In-Market UserInterest.
    IN_MARKET_USER_INTEREST = 3

    # An age range.
    AGE_RANGE = 4

    # A gender.
    GENDER = 5
  end
end