Class: Google::Ads::DataManager::V1::SearchPartnerLinksResponse
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::SearchPartnerLinksResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/partner_link_service.rb
Overview
Response from the SearchPartnerLinksRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#partner_links ⇒ ::Array<::Google::Ads::DataManager::V1::PartnerLink>
The partner links for the given account.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
114 115 116 117 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 114 class SearchPartnerLinksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#partner_links ⇒ ::Array<::Google::Ads::DataManager::V1::PartnerLink>
Returns The partner links for the given account.
114 115 116 117 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 114 class SearchPartnerLinksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |