Class: Google::Ads::DataManager::V1::SizeInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list.rb

Overview

Estimated number of members in this user list in different target networks.

Instance Attribute Summary collapse

Instance Attribute Details

#display_network_members_count::Integer (readonly)

Returns Output only. Estimated number of members in this user list, on the Google Display Network.

Returns:

  • (::Integer)

    Output only. Estimated number of members in this user list, on the Google Display Network.



154
155
156
157
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 154

class SizeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gmail_members_count::Integer (readonly)

Returns Output only. Estimated number of members in this user list on Gmail.

Returns:

  • (::Integer)

    Output only. Estimated number of members in this user list on Gmail.



154
155
156
157
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 154

class SizeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#search_network_members_count::Integer (readonly)

Returns Output only. Estimated number of members in this user list in the google.com domain. These are the members available for targeting in Search campaigns.

Returns:

  • (::Integer)

    Output only. Estimated number of members in this user list in the google.com domain. These are the members available for targeting in Search campaigns.



154
155
156
157
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 154

class SizeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#youtube_members_count::Integer (readonly)

Returns Output only. Estimated number of members in this user list on YouTube.

Returns:

  • (::Integer)

    Output only. Estimated number of members in this user list on YouTube.



154
155
156
157
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 154

class SizeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end