Module: Google::Ads::DataManager::V1::TermsOfServiceStatus

Defined in:
proto_docs/google/ads/datamanager/v1/terms_of_service.rb

Overview

Represents the caller's decision to accept or reject the terms of service.

Constant Summary collapse

TERMS_OF_SERVICE_STATUS_UNSPECIFIED =

Not specified.

0
ACCEPTED =

Status indicating the caller has chosen to accept the terms of service.

1
REJECTED =

Status indicating the caller has chosen to reject the terms of service.

2