Class: Google::Ads::DataManager::V1::UpdateUserListRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_service.rb

Overview

Request message for UpdateUserList.

Instance Attribute Summary collapse

Instance Attribute Details

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update.

Returns:



130
131
132
133
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 130

class UpdateUserListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_list::Google::Ads::DataManager::V1::UserList

Returns Required. The user list to update.

The user list's name field is used to identify the user list to update. Format: accountTypes/{account_type}/accounts/{account}/userLists/{user_list}.

Returns:

  • (::Google::Ads::DataManager::V1::UserList)

    Required. The user list to update.

    The user list's name field is used to identify the user list to update. Format: accountTypes/{account_type}/accounts/{account}/userLists/{user_list}



130
131
132
133
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 130

class UpdateUserListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. If true, the request is validated but not executed.

Returns:

  • (::Boolean)

    Optional. If true, the request is validated but not executed.



130
131
132
133
# File 'proto_docs/google/ads/datamanager/v1/user_list_service.rb', line 130

class UpdateUserListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end