Class: Google::Ads::DataManager::V1::UserData

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_data.rb

Overview

Data that identifies the user. At least one identifier is required.

Instance Attribute Summary collapse

Instance Attribute Details

#user_identifiers::Array<::Google::Ads::DataManager::V1::UserIdentifier>

Returns Required. The identifiers for the user. It's possible to provide multiple instances of the same type of data (for example, multiple email addresses). To increase the likelihood of a match, provide as many identifiers as possible. At most 10 userIdentifiers can be provided in a single AudienceMember or Event.

Returns:

  • (::Array<::Google::Ads::DataManager::V1::UserIdentifier>)

    Required. The identifiers for the user. It's possible to provide multiple instances of the same type of data (for example, multiple email addresses). To increase the likelihood of a match, provide as many identifiers as possible. At most 10 userIdentifiers can be provided in a single AudienceMember or Event.



33
34
35
36
# File 'proto_docs/google/ads/datamanager/v1/user_data.rb', line 33

class UserData
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end