Class: Google::Ads::DataManager::V1::UserIdentifier

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_data.rb

Overview

A single identifier for the user.

Instance Attribute Summary collapse

Instance Attribute Details

#address::Google::Ads::DataManager::V1::AddressInfo

Returns The known components of a user's address. Holds a grouping of identifiers that are matched all at once.

Note: The following fields are mutually exclusive: address, email_address, phone_number. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Ads::DataManager::V1::AddressInfo)

    The known components of a user's address. Holds a grouping of identifiers that are matched all at once.

    Note: The following fields are mutually exclusive: address, email_address, phone_number. If a field in that set is populated, all other fields in the set will automatically be cleared.



56
57
58
59
# File 'proto_docs/google/ads/datamanager/v1/user_data.rb', line 56

class UserIdentifier
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#email_address::String

Returns Hashed email address using SHA-256 hash function after normalization.

Note: The following fields are mutually exclusive: email_address, phone_number, address. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Hashed email address using SHA-256 hash function after normalization.

    Note: The following fields are mutually exclusive: email_address, phone_number, address. If a field in that set is populated, all other fields in the set will automatically be cleared.



56
57
58
59
# File 'proto_docs/google/ads/datamanager/v1/user_data.rb', line 56

class UserIdentifier
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#phone_number::String

Returns Hashed phone number using SHA-256 hash function after normalization (E164 standard).

Note: The following fields are mutually exclusive: phone_number, email_address, address. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Hashed phone number using SHA-256 hash function after normalization (E164 standard).

    Note: The following fields are mutually exclusive: phone_number, email_address, address. If a field in that set is populated, all other fields in the set will automatically be cleared.



56
57
58
59
# File 'proto_docs/google/ads/datamanager/v1/user_data.rb', line 56

class UserIdentifier
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end