Module: Google::Ads::DataManager::V1::UserList::ClosingReason
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list.rb
Overview
Indicates the reason why the user list was closed. This enum is only used when a list is auto-closed by the system.
Constant Summary collapse
- CLOSING_REASON_UNSPECIFIED =
Not specified.
0- UNUSED =
The user list was closed because it has not been used in targeting recently. See https://support.google.com/google-ads/answer/2472738 for details.
1