Class: Google::Ads::DataManager::V1::UserListGlobalLicense

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_global_license.rb

Overview

A user list global license.

This feature is only available to data partners.

Instance Attribute Summary collapse

Instance Attribute Details

#historical_pricings::Array<::Google::Ads::DataManager::V1::UserListLicensePricing> (readonly)

Returns Output only. Pricing history of this user list license.

This field is read-only.

Returns:



59
60
61
62
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 59

class UserListGlobalLicense
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#license_type::Google::Ads::DataManager::V1::UserListGlobalLicenseType

Returns Immutable. Product type of client customer which the user list is being licensed to.

Returns:



59
60
61
62
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 59

class UserListGlobalLicense
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#metrics::Google::Ads::DataManager::V1::UserListLicenseMetrics (readonly)

Returns Output only. Metrics related to this license

This field is read-only and only populated if the start and end dates are set in the ListUserListGlobalLicenses call.

Returns:



59
60
61
62
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 59

class UserListGlobalLicense
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the user list global license.

Returns:

  • (::String)

    Identifier. The resource name of the user list global license.



59
60
61
62
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 59

class UserListGlobalLicense
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pricing::Google::Ads::DataManager::V1::UserListLicensePricing

Returns Optional. UserListGlobalLicense pricing.

Returns:



59
60
61
62
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 59

class UserListGlobalLicense
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status::Google::Ads::DataManager::V1::UserListLicenseStatus

Returns Optional. Status of UserListGlobalLicense - ENABLED or DISABLED.

Returns:



59
60
61
62
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 59

class UserListGlobalLicense
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_list_display_name::String (readonly)

Returns Output only. Name of the user list being licensed.

This field is read-only.

Returns:

  • (::String)

    Output only. Name of the user list being licensed.

    This field is read-only.



59
60
61
62
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 59

class UserListGlobalLicense
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_list_id::Integer

Returns Immutable. ID of the user list being licensed.

Returns:

  • (::Integer)

    Immutable. ID of the user list being licensed.



59
60
61
62
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 59

class UserListGlobalLicense
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end