Class: Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_global_license.rb

Overview

Information about a customer of a user list global license. This will automatically be created by the system when a customer purchases a global license.

Instance Attribute Summary collapse

Instance Attribute Details

#client_account_display_name::String (readonly)

Returns Output only. Name of client customer which the user list is being licensed to.

Returns:

  • (::String)

    Output only. Name of client customer which the user list is being licensed to.



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_account_id::Integer (readonly)

Returns Output only. ID of client customer which the user list is being licensed to.

Returns:

  • (::Integer)

    Output only. ID of client customer which the user list is being licensed to.



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#client_account_type::Google::Ads::DataManager::V1::UserListLicenseClientAccountType (readonly)

Returns Output only. Product type of client customer which the user list is being licensed to.

Returns:



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#historical_pricings::Array<::Google::Ads::DataManager::V1::UserListLicensePricing> (readonly)

Returns Output only. Pricing history of this user list license.

Returns:



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#license_type::Google::Ads::DataManager::V1::UserListGlobalLicenseType (readonly)

Returns Output only. Product type of client customer which the user list is being licensed to.

Returns:



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#metrics::Google::Ads::DataManager::V1::UserListLicenseMetrics (readonly)

Returns Output only. Metrics related to this license

This field is only populated if the start and end dates are set in the ListUserListGlobalLicenseCustomerInfos call.

Returns:



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the user list global license customer.

Returns:

  • (::String)

    Identifier. The resource name of the user list global license customer.



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#pricing::Google::Ads::DataManager::V1::UserListLicensePricing (readonly)

Returns Output only. UserListDirectLicense pricing.

Returns:



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status::Google::Ads::DataManager::V1::UserListLicenseStatus (readonly)

Returns Output only. Status of UserListDirectLicense - ENABLED or DISABLED.

Returns:



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_list_display_name::String (readonly)

Returns Output only. Name of the user list being licensed.

Returns:

  • (::String)

    Output only. Name of the user list being licensed.



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#user_list_id::Integer (readonly)

Returns Output only. ID of the user list being licensed.

Returns:

  • (::Integer)

    Output only. ID of the user list being licensed.



107
108
109
110
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license.rb', line 107

class UserListGlobalLicenseCustomerInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end