Class: Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb

Overview

Client for the UserListGlobalLicenseService service.

Service for managing user list global licenses. Delete is not a supported operation for UserListGlobalLicenses. Callers should update the license status to DISABLED to instead to deactivate a license.

This feature is only available to data partners.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#account_path, #user_list_global_license_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new UserListGlobalLicenseService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the UserListGlobalLicenseService client.

Yield Parameters:



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 128

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/ads/datamanager/v1/user_list_global_license_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @user_list_global_license_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Ads::DataManager::V1::UserListGlobalLicenseService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @user_list_global_license_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the UserListGlobalLicenseService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all UserListGlobalLicenseService clients
::Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 66

def self.configure
  @configure ||= begin
    namespace = ["Google", "Ads", "DataManager", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the UserListGlobalLicenseService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



98
99
100
101
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 98

def configure
  yield @config if block_given?
  @config
end

#create_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense #create_user_list_global_license(parent: nil, user_list_global_license: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

Creates a user list global license.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::CreateUserListGlobalLicenseRequest.new

# Call the create_user_list_global_license method.
result = client.create_user_list_global_license request

# The returned object is of type Google::Ads::DataManager::V1::UserListGlobalLicense.
p result

Overloads:

  • #create_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

    Pass arguments to create_user_list_global_license via a request object, either of type CreateUserListGlobalLicenseRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::CreateUserListGlobalLicenseRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_user_list_global_license(parent: nil, user_list_global_license: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

    Pass arguments to create_user_list_global_license via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The account that owns the user list being licensed. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}

    • user_list_global_license (::Google::Ads::DataManager::V1::UserListGlobalLicense, ::Hash) (defaults to: nil)

      Required. The user list global license to create.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 239

def create_user_list_global_license request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::CreateUserListGlobalLicenseRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_user_list_global_license..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_user_list_global_license.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_user_list_global_license.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.call_rpc :create_user_list_global_license, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense #get_user_list_global_license(name: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

Retrieves a user list global license.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::GetUserListGlobalLicenseRequest.new

# Call the get_user_list_global_license method.
result = client.get_user_list_global_license request

# The returned object is of type Google::Ads::DataManager::V1::UserListGlobalLicense.
p result

Overloads:

  • #get_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

    Pass arguments to get_user_list_global_license via a request object, either of type GetUserListGlobalLicenseRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::GetUserListGlobalLicenseRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_user_list_global_license(name: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

    Pass arguments to get_user_list_global_license via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the user list global license.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 417

def get_user_list_global_license request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::GetUserListGlobalLicenseRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_user_list_global_license..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_user_list_global_license.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_user_list_global_license.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.call_rpc :get_user_list_global_license, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_user_list_global_license_customer_infos(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo> #list_user_list_global_license_customer_infos(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo>

Lists all customer info for a user list global license.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::ListUserListGlobalLicenseCustomerInfosRequest.new

# Call the list_user_list_global_license_customer_infos method.
result = client.list_user_list_global_license_customer_infos request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo.
  p item
end

Overloads:

  • #list_user_list_global_license_customer_infos(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo>

    Pass arguments to list_user_list_global_license_customer_infos via a request object, either of type ListUserListGlobalLicenseCustomerInfosRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::ListUserListGlobalLicenseCustomerInfosRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_user_list_global_license_customer_infos(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo>

    Pass arguments to list_user_list_global_license_customer_infos via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The global license whose customer info are being queried. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}/userListGlobalLicenses/{USER_LIST_GLOBAL_LICENSE_ID}. To list all global license customer info under an account, replace the user list global license id with a '-' (for example, accountTypes/DATA_PARTNER/accounts/123/userListGlobalLicenses/-)

    • filter (::String) (defaults to: nil)

      Optional. A filter string to apply to the list request. All fields need to be on the left hand side of each condition (for example: user_list_id = 123). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case.

      Supported Operations:

      • AND
      • =
      • !=
      • >
      • >=
      • <
      • <=

      Unsupported Fields:

      • name (use get method instead)
      • historical_pricings and all its subfields
      • pricing.start_time
      • pricing.end_time
    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of licenses to return. The service may return fewer than this value. If unspecified, at most 50 licenses will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListUserListDirectLicense call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListUserListDirectLicense must match the call that provided the page token.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 681

def list_user_list_global_license_customer_infos request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::ListUserListGlobalLicenseCustomerInfosRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_user_list_global_license_customer_infos..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_user_list_global_license_customer_infos.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_user_list_global_license_customer_infos.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.call_rpc :list_user_list_global_license_customer_infos, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @user_list_global_license_service_stub, :list_user_list_global_license_customer_infos, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_user_list_global_licenses(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicense> #list_user_list_global_licenses(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicense>

Lists all user list global licenses owned by the parent account.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::ListUserListGlobalLicensesRequest.new

# Call the list_user_list_global_licenses method.
result = client.list_user_list_global_licenses request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Ads::DataManager::V1::UserListGlobalLicense.
  p item
end

Overloads:

  • #list_user_list_global_licenses(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicense>

    Pass arguments to list_user_list_global_licenses via a request object, either of type ListUserListGlobalLicensesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::ListUserListGlobalLicensesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_user_list_global_licenses(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicense>

    Pass arguments to list_user_list_global_licenses via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The account whose licenses are being queried. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}

    • filter (::String) (defaults to: nil)

      Optional. A filter string to apply to the list request. All fields need to be on the left hand side of each condition (for example: user_list_id = 123). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case.

      Supported Operations:

      • AND
      • =
      • !=
      • >
      • >=
      • <
      • <=

      Unsupported Fields:

      • name (use get method instead)
      • historical_pricings and all its subfields
      • pricing.start_time
      • pricing.end_time
    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of licenses to return. The service may return fewer than this value. If unspecified, at most 50 licenses will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListUserListGlobalLicense call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListUserListDirectLicense must match the call that provided the page token.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 546

def list_user_list_global_licenses request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::ListUserListGlobalLicensesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_user_list_global_licenses..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_user_list_global_licenses.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_user_list_global_licenses.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.call_rpc :list_user_list_global_licenses, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @user_list_global_license_service_stub, :list_user_list_global_licenses, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


184
185
186
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 184

def logger
  @user_list_global_license_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


108
109
110
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 108

def universe_domain
  @user_list_global_license_service_stub.universe_domain
end

#update_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense #update_user_list_global_license(user_list_global_license: nil, update_mask: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

Updates a user list global license.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::UpdateUserListGlobalLicenseRequest.new

# Call the update_user_list_global_license method.
result = client.update_user_list_global_license request

# The returned object is of type Google::Ads::DataManager::V1::UserListGlobalLicense.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/client.rb', line 330

def update_user_list_global_license request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::UpdateUserListGlobalLicenseRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_user_list_global_license..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.user_list_global_license&.name
    header_params["user_list_global_license.name"] = request.user_list_global_license.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_user_list_global_license.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_user_list_global_license.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.call_rpc :update_user_list_global_license, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end