Class: Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb

Overview

REST client for the UserListGlobalLicenseService service.

Service for managing user list global licenses. Delete is not a supported operation for UserListGlobalLicenses. Callers should update the license status to DISABLED to instead to deactivate a license.

This feature is only available to data partners.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#account_path, #user_list_global_license_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new UserListGlobalLicenseService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the UserListGlobalLicenseService client.

Yield Parameters:



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 130

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @user_list_global_license_service_stub = ::Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @user_list_global_license_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the UserListGlobalLicenseService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all UserListGlobalLicenseService clients
::Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 68

def self.configure
  @configure ||= begin
    namespace = ["Google", "Ads", "DataManager", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the UserListGlobalLicenseService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



100
101
102
103
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 100

def configure
  yield @config if block_given?
  @config
end

#create_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense #create_user_list_global_license(parent: nil, user_list_global_license: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

Creates a user list global license.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::CreateUserListGlobalLicenseRequest.new

# Call the create_user_list_global_license method.
result = client.create_user_list_global_license request

# The returned object is of type Google::Ads::DataManager::V1::UserListGlobalLicense.
p result

Overloads:

  • #create_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

    Pass arguments to create_user_list_global_license via a request object, either of type CreateUserListGlobalLicenseRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::CreateUserListGlobalLicenseRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_user_list_global_license(parent: nil, user_list_global_license: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

    Pass arguments to create_user_list_global_license via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The account that owns the user list being licensed. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}

    • user_list_global_license (::Google::Ads::DataManager::V1::UserListGlobalLicense, ::Hash) (defaults to: nil)

      Required. The user list global license to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 231

def create_user_list_global_license request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::CreateUserListGlobalLicenseRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_user_list_global_license..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_user_list_global_license.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_user_list_global_license.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.create_user_list_global_license request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense #get_user_list_global_license(name: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

Retrieves a user list global license.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::GetUserListGlobalLicenseRequest.new

# Call the get_user_list_global_license method.
result = client.get_user_list_global_license request

# The returned object is of type Google::Ads::DataManager::V1::UserListGlobalLicense.
p result

Overloads:

  • #get_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

    Pass arguments to get_user_list_global_license via a request object, either of type GetUserListGlobalLicenseRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::GetUserListGlobalLicenseRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_user_list_global_license(name: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

    Pass arguments to get_user_list_global_license via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the user list global license.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 395

def get_user_list_global_license request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::GetUserListGlobalLicenseRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_user_list_global_license..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_user_list_global_license.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_user_list_global_license.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.get_user_list_global_license request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_user_list_global_license_customer_infos(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo> #list_user_list_global_license_customer_infos(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo>

Lists all customer info for a user list global license.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::ListUserListGlobalLicenseCustomerInfosRequest.new

# Call the list_user_list_global_license_customer_infos method.
result = client.list_user_list_global_license_customer_infos request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo.
  p item
end

Overloads:

  • #list_user_list_global_license_customer_infos(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo>

    Pass arguments to list_user_list_global_license_customer_infos via a request object, either of type ListUserListGlobalLicenseCustomerInfosRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::ListUserListGlobalLicenseCustomerInfosRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_user_list_global_license_customer_infos(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicenseCustomerInfo>

    Pass arguments to list_user_list_global_license_customer_infos via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The global license whose customer info are being queried. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}/userListGlobalLicenses/{USER_LIST_GLOBAL_LICENSE_ID}. To list all global license customer info under an account, replace the user list global license id with a '-' (for example, accountTypes/DATA_PARTNER/accounts/123/userListGlobalLicenses/-)

    • filter (::String) (defaults to: nil)

      Optional. A filter string to apply to the list request. All fields need to be on the left hand side of each condition (for example: user_list_id = 123). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case.

      Supported Operations:

      • AND
      • =
      • !=
      • >
      • >=
      • <
      • <=

      Unsupported Fields:

      • name (use get method instead)
      • historical_pricings and all its subfields
      • pricing.start_time
      • pricing.end_time
    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of licenses to return. The service may return fewer than this value. If unspecified, at most 50 licenses will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListUserListDirectLicense call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListUserListDirectLicense must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 645

def list_user_list_global_license_customer_infos request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::ListUserListGlobalLicenseCustomerInfosRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_user_list_global_license_customer_infos..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_user_list_global_license_customer_infos.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_user_list_global_license_customer_infos.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.list_user_list_global_license_customer_infos request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @user_list_global_license_service_stub, :list_user_list_global_license_customer_infos, "user_list_global_license_customer_infos", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_user_list_global_licenses(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicense> #list_user_list_global_licenses(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicense>

Lists all user list global licenses owned by the parent account.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::ListUserListGlobalLicensesRequest.new

# Call the list_user_list_global_licenses method.
result = client.list_user_list_global_licenses request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Ads::DataManager::V1::UserListGlobalLicense.
  p item
end

Overloads:

  • #list_user_list_global_licenses(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicense>

    Pass arguments to list_user_list_global_licenses via a request object, either of type ListUserListGlobalLicensesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Ads::DataManager::V1::ListUserListGlobalLicensesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_user_list_global_licenses(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListGlobalLicense>

    Pass arguments to list_user_list_global_licenses via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The account whose licenses are being queried. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}

    • filter (::String) (defaults to: nil)

      Optional. A filter string to apply to the list request. All fields need to be on the left hand side of each condition (for example: user_list_id = 123). Fields must be specified using either all camel case or all snake case. Don't use a combination of camel case and snake case.

      Supported Operations:

      • AND
      • =
      • !=
      • >
      • >=
      • <
      • <=

      Unsupported Fields:

      • name (use get method instead)
      • historical_pricings and all its subfields
      • pricing.start_time
      • pricing.end_time
    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of licenses to return. The service may return fewer than this value. If unspecified, at most 50 licenses will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListUserListGlobalLicense call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListUserListDirectLicense must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 517

def list_user_list_global_licenses request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::ListUserListGlobalLicensesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_user_list_global_licenses..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_user_list_global_licenses.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_user_list_global_licenses.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.list_user_list_global_licenses request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @user_list_global_license_service_stub, :list_user_list_global_licenses, "user_list_global_licenses", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


177
178
179
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 177

def logger
  @user_list_global_license_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


110
111
112
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 110

def universe_domain
  @user_list_global_license_service_stub.universe_domain
end

#update_user_list_global_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense #update_user_list_global_license(user_list_global_license: nil, update_mask: nil) ⇒ ::Google::Ads::DataManager::V1::UserListGlobalLicense

Updates a user list global license.

This feature is only available to data partners.

Examples:

Basic example

require "google/ads/data_manager/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Ads::DataManager::V1::UserListGlobalLicenseService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Ads::DataManager::V1::UpdateUserListGlobalLicenseRequest.new

# Call the update_user_list_global_license method.
result = client.update_user_list_global_license request

# The returned object is of type Google::Ads::DataManager::V1::UserListGlobalLicense.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/google/ads/data_manager/v1/user_list_global_license_service/rest/client.rb', line 315

def update_user_list_global_license request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::UpdateUserListGlobalLicenseRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_user_list_global_license..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Ads::DataManager::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_user_list_global_license.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_user_list_global_license.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @user_list_global_license_service_stub.update_user_list_global_license request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end