Class: Google::Ads::DataManager::V1::UserListLicenseMetrics

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/user_list_license_metrics.rb

Overview

Metrics related to a user list license.

Instance Attribute Summary collapse

Instance Attribute Details

#click_count::Integer (readonly)

Returns Output only. The number of clicks for the user list license.

Returns:

  • (::Integer)

    Output only. The number of clicks for the user list license.



48
49
50
51
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_metrics.rb', line 48

class UserListLicenseMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_date::Integer (readonly)

Returns Output only. The end date (inclusive) of the metrics in the format YYYYMMDD. For example, 20260102 represents January 2, 2026. If start_date is used in the filter, end_date is also required. If neither start_date nor end_date are included in the filter, the UserListLicenseMetrics fields will not be populated in the response.

Returns:

  • (::Integer)

    Output only. The end date (inclusive) of the metrics in the format YYYYMMDD. For example, 20260102 represents January 2, 2026. If start_date is used in the filter, end_date is also required. If neither start_date nor end_date are included in the filter, the UserListLicenseMetrics fields will not be populated in the response.



48
49
50
51
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_metrics.rb', line 48

class UserListLicenseMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#impression_count::Integer (readonly)

Returns Output only. The number of impressions for the user list license.

Returns:

  • (::Integer)

    Output only. The number of impressions for the user list license.



48
49
50
51
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_metrics.rb', line 48

class UserListLicenseMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#revenue_usd_micros::Integer (readonly)

Returns Output only. The revenue for the user list license in USD micros.

Returns:

  • (::Integer)

    Output only. The revenue for the user list license in USD micros.



48
49
50
51
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_metrics.rb', line 48

class UserListLicenseMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_date::Integer (readonly)

Returns Output only. The start date (inclusive) of the metrics in the format YYYYMMDD. For example, 20260102 represents January 2, 2026. If end_date is used in the filter, start_date is also required. If neither start_date nor end_date are included in the filter, the UserListLicenseMetrics fields will not be populated in the response.

Returns:

  • (::Integer)

    Output only. The start date (inclusive) of the metrics in the format YYYYMMDD. For example, 20260102 represents January 2, 2026. If end_date is used in the filter, start_date is also required. If neither start_date nor end_date are included in the filter, the UserListLicenseMetrics fields will not be populated in the response.



48
49
50
51
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_metrics.rb', line 48

class UserListLicenseMetrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end