Class: Google::Ads::DataManager::V1::WarningInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::WarningInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/processing_errors.rb
Overview
Warning counts for each type of warning.
Instance Attribute Summary collapse
-
#warning_counts ⇒ ::Array<::Google::Ads::DataManager::V1::WarningCount>
A list of warnings and counts per warning reason.
Instance Attribute Details
#warning_counts ⇒ ::Array<::Google::Ads::DataManager::V1::WarningCount>
Returns A list of warnings and counts per warning reason.
50 51 52 53 |
# File 'proto_docs/google/ads/datamanager/v1/processing_errors.rb', line 50 class WarningInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |