Class: Google::Ads::DataManager::V1::AdEvent
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::AdEvent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/ad_event.rb
Overview
An ad event.
Defined Under Namespace
Modules: EventSubtype, EventType
Instance Attribute Summary collapse
-
#ad_format ⇒ ::Google::Ads::DataManager::V1::AdFormat
Enum value for ad format.
-
#ad_format_string ⇒ ::String
String value for ad format.
-
#ad_group_id ⇒ ::String
Optional.
-
#ad_height ⇒ ::Integer
Optional.
-
#ad_id ⇒ ::String
Optional.
-
#ad_placement ⇒ ::Google::Ads::DataManager::V1::AdPlacement
Enum value for ad placement.
-
#ad_placement_string ⇒ ::String
String value for ad placement.
-
#ad_type ⇒ ::Google::Ads::DataManager::V1::AdType
Enum value for ad type.
-
#ad_type_string ⇒ ::String
String value for ad type.
-
#ad_width ⇒ ::Integer
Optional.
-
#advertiser_id ⇒ ::String
Required.
-
#attribution_hint ⇒ ::Google::Ads::DataManager::V1::AttributionHint
Optional.
-
#campaign_id ⇒ ::String
Required.
-
#campaign_name ⇒ ::String
Required.
-
#device_info ⇒ ::Google::Ads::DataManager::V1::DeviceInfo
Optional.
-
#event_id ⇒ ::String
Optional.
-
#event_subtype ⇒ ::Google::Ads::DataManager::V1::AdEvent::EventSubtype
Enum value for event subtype.
-
#event_subtype_string ⇒ ::String
String value for event subtype.
-
#event_type ⇒ ::Google::Ads::DataManager::V1::AdEvent::EventType
Required.
-
#measurement_allowed ⇒ ::Boolean
Optional.
-
#medium ⇒ ::String
Required.
-
#mobile_device_id ⇒ ::String
Optional.
-
#platform ⇒ ::Google::Ads::DataManager::V1::Platform
Enum value for platform.
-
#platform_string ⇒ ::String
String value for platform.
-
#platform_type ⇒ ::Google::Ads::DataManager::V1::PlatformType
Enum value for platform type.
-
#platform_type_string ⇒ ::String
String value for platform type.
-
#region_code ⇒ ::String
Required.
-
#source ⇒ ::String
Required.
-
#targeting_type ⇒ ::Google::Ads::DataManager::V1::TargetingType
Enum value for targeting type.
-
#targeting_type_string ⇒ ::String
String value for targeting type.
-
#timestamp ⇒ ::Google::Protobuf::Timestamp
Required.
-
#user_data ⇒ ::Google::Ads::DataManager::V1::UserData
Optional.
-
#viewability_info ⇒ ::Google::Ads::DataManager::V1::ViewabilityInfo
Required.
Instance Attribute Details
#ad_format ⇒ ::Google::Ads::DataManager::V1::AdFormat
Returns Enum value for ad format.
Note: The following fields are mutually exclusive: ad_format, ad_format_string. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_format_string ⇒ ::String
Returns String value for ad format.
Note: The following fields are mutually exclusive: ad_format_string, ad_format. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_group_id ⇒ ::String
Returns Optional. The ID of the associated ad group.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_height ⇒ ::Integer
Returns Optional. The height of the ad in pixels.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_id ⇒ ::String
Returns Optional. The ID of the associated ad within the group.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_placement ⇒ ::Google::Ads::DataManager::V1::AdPlacement
Returns Enum value for ad placement.
Note: The following fields are mutually exclusive: ad_placement, ad_placement_string. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_placement_string ⇒ ::String
Returns String value for ad placement.
Note: The following fields are mutually exclusive: ad_placement_string, ad_placement. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_type ⇒ ::Google::Ads::DataManager::V1::AdType
Returns Enum value for ad type.
Note: The following fields are mutually exclusive: ad_type, ad_type_string. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_type_string ⇒ ::String
Returns String value for ad type.
Note: The following fields are mutually exclusive: ad_type_string, ad_type. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#ad_width ⇒ ::Integer
Returns Optional. The width of the ad in pixels.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#advertiser_id ⇒ ::String
Returns Required. The ID of the advertiser for the ad event.
This must match the ID sent in the linking flow.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#attribution_hint ⇒ ::Google::Ads::DataManager::V1::AttributionHint
Returns Optional. The partner-assumed attribution status for this ad event.
This acts only as a signal for how the partner assumed attribution played out, and does not force an end result in final reports.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#campaign_id ⇒ ::String
Returns Required. The ID of the associated campaign.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#campaign_name ⇒ ::String
Returns Required. The name of the associated campaign.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#device_info ⇒ ::Google::Ads::DataManager::V1::DeviceInfo
Returns Optional. Information gathered about the device being used when the ad event happened.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#event_id ⇒ ::String
Returns Optional. An ID created and managed by the caller that uniquely identifies this event.
Required if you want to deduplicate ad events that are included in multiple requests. Otherwise, this field is optional.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#event_subtype ⇒ ::Google::Ads::DataManager::V1::AdEvent::EventSubtype
Returns Enum value for event subtype.
Note: The following fields are mutually exclusive: event_subtype, event_subtype_string. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#event_subtype_string ⇒ ::String
Returns String value for event subtype.
Note: The following fields are mutually exclusive: event_subtype_string, event_subtype. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#event_type ⇒ ::Google::Ads::DataManager::V1::AdEvent::EventType
Returns Required. The type of the event.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#measurement_allowed ⇒ ::Boolean
Returns Optional. Represents if the row is allowed to be used for measurement purposes, as governed by applicable privacy laws within regional jurisdiction.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#medium ⇒ ::String
Returns Required. The medium of the ad, akin to the Google Analytics medium.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#mobile_device_id ⇒ ::String
Returns Optional. The device ID of the device that the ad was served to.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#platform ⇒ ::Google::Ads::DataManager::V1::Platform
Returns Enum value for platform.
Note: The following fields are mutually exclusive: platform, platform_string. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#platform_string ⇒ ::String
Returns String value for platform.
Note: The following fields are mutually exclusive: platform_string, platform. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#platform_type ⇒ ::Google::Ads::DataManager::V1::PlatformType
Returns Enum value for platform type.
Note: The following fields are mutually exclusive: platform_type, platform_type_string. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#platform_type_string ⇒ ::String
Returns String value for platform type.
Note: The following fields are mutually exclusive: platform_type_string, platform_type. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#region_code ⇒ ::String
Returns Required. The ISO 3166-2 country plus subdivision.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#source ⇒ ::String
Returns Required. The platform source of the ad, akin to the Google Analytics source.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#targeting_type ⇒ ::Google::Ads::DataManager::V1::TargetingType
Returns Enum value for targeting type.
Note: The following fields are mutually exclusive: targeting_type, targeting_type_string. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#targeting_type_string ⇒ ::String
Returns String value for targeting type.
Note: The following fields are mutually exclusive: targeting_type_string, targeting_type. If a field in that set is populated, all other fields in the set will automatically be cleared.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#timestamp ⇒ ::Google::Protobuf::Timestamp
Returns Required. The time the event occurred.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#user_data ⇒ ::Google::Ads::DataManager::V1::UserData
Returns Optional. Multiple pieces of user-provided data, representing the user the event is associated with.
It is possible to provide multiple instances of the same type of data (e.g. email address). The more data provided, the more likely a match will be found.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |
#viewability_info ⇒ ::Google::Ads::DataManager::V1::ViewabilityInfo
Returns Required. Details of the viewability of the ad served.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'proto_docs/google/ads/datamanager/v1/ad_event.rb', line 170 class AdEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the event. module EventType # Unspecified event type. EVENT_TYPE_UNSPECIFIED = 0 # View event. EVENT_TYPE_VIEW = 1 # Click event. EVENT_TYPE_CLICK = 2 end # Additional classification about the type of ad event. module EventSubtype # Unspecified event subtype. EVENT_SUBTYPE_UNSPECIFIED = 0 # Impression event. EVENT_SUBTYPE_IMPRESSION = 1 # Engaged view event. EVENT_SUBTYPE_ENGAGED_VIEW = 2 # Onsite click event. EVENT_SUBTYPE_ONSITE_CLICK = 3 # Outbound click event. EVENT_SUBTYPE_OUTBOUND_CLICK = 4 end end |