Class: Google::Ads::DataManager::V1::AdIdentifiers

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/event.rb

Overview

Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).

Instance Attribute Summary collapse

Instance Attribute Details

#gbraid::String

Returns Optional. The click identifier for clicks associated with app events and originating from iOS devices starting with iOS14.

Returns:

  • (::String)

    Optional. The click identifier for clicks associated with app events and originating from iOS devices starting with iOS14.



142
143
144
145
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 142

class AdIdentifiers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gclid::String

Returns Optional. The Google click ID (gclid) associated with this event.

Returns:

  • (::String)

    Optional. The Google click ID (gclid) associated with this event.



142
143
144
145
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 142

class AdIdentifiers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#landing_page_device_info::Google::Ads::DataManager::V1::DeviceInfo

Returns Optional. Information gathered about the device being used (if any) at the time of landing onto the advertiser’s site after interacting with the ad.

Returns:



142
143
144
145
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 142

class AdIdentifiers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mobile_device_id::String

Returns Optional. The mobile identifier for advertisers. This would be IDFA on iOS, AdID on Android, or other platforms’ identifiers for advertisers.

Returns:

  • (::String)

    Optional. The mobile identifier for advertisers. This would be IDFA on iOS, AdID on Android, or other platforms’ identifiers for advertisers.



142
143
144
145
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 142

class AdIdentifiers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#session_attributes::String

Returns Optional. Session attributes for event attribution and modeling.

Returns:

  • (::String)

    Optional. Session attributes for event attribution and modeling.



142
143
144
145
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 142

class AdIdentifiers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#wbraid::String

Returns Optional. The click identifier for clicks associated with web events and originating from iOS devices starting with iOS14.

Returns:

  • (::String)

    Optional. The click identifier for clicks associated with web events and originating from iOS devices starting with iOS14.



142
143
144
145
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 142

class AdIdentifiers
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end