Class: Google::Ads::DataManager::V1::AudienceMember
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::AudienceMember
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/audience.rb
Overview
The audience member to be operated on.
Instance Attribute Summary collapse
-
#consent ⇒ ::Google::Ads::DataManager::V1::Consent
Optional.
-
#destination_references ⇒ ::Array<::String>
Optional.
-
#mobile_data ⇒ ::Google::Ads::DataManager::V1::MobileData
Data identifying the user's mobile devices.
- #pair_data ⇒ ::Google::Ads::DataManager::V1::PairData
-
#ppid_data ⇒ ::Google::Ads::DataManager::V1::PpidData
Data related to publisher provided identifiers.
-
#user_data ⇒ ::Google::Ads::DataManager::V1::UserData
User-provided data that identifies the user.
-
#user_id_data ⇒ ::Google::Ads::DataManager::V1::UserIdData
Data related to unique identifiers for a user, as defined by the advertiser.
Instance Attribute Details
#consent ⇒ ::Google::Ads::DataManager::V1::Consent
Returns Optional. The consent setting for the user.
64 65 66 67 |
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 64 class AudienceMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_references ⇒ ::Array<::String>
Returns Optional. Defines which Destination to send the audience member to.
64 65 66 67 |
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 64 class AudienceMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mobile_data ⇒ ::Google::Ads::DataManager::V1::MobileData
Returns Data identifying the user's mobile devices.
Note: The following fields are mutually exclusive: mobile_data, user_data, pair_data, user_id_data, ppid_data. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 64 class AudienceMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pair_data ⇒ ::Google::Ads::DataManager::V1::PairData
Returns Publisher Advertiser Identity Reconciliation (PAIR) IDs.
This feature is only available to data partners.
Note: The following fields are mutually exclusive: pair_data, user_data, mobile_data, user_id_data, ppid_data. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 64 class AudienceMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ppid_data ⇒ ::Google::Ads::DataManager::V1::PpidData
Returns Data related to publisher provided identifiers.
This feature is only available to data partners.
Note: The following fields are mutually exclusive: ppid_data, user_data, pair_data, mobile_data, user_id_data. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 64 class AudienceMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_data ⇒ ::Google::Ads::DataManager::V1::UserData
Returns User-provided data that identifies the user.
Note: The following fields are mutually exclusive: user_data, pair_data, mobile_data, user_id_data, ppid_data. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 64 class AudienceMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_id_data ⇒ ::Google::Ads::DataManager::V1::UserIdData
Returns Data related to unique identifiers for a user, as defined by the advertiser.
Note: The following fields are mutually exclusive: user_id_data, user_data, pair_data, mobile_data, ppid_data. If a field in that set is populated, all other fields in the set will automatically be cleared.
64 65 66 67 |
# File 'proto_docs/google/ads/datamanager/v1/audience.rb', line 64 class AudienceMember include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |