Class: Google::Ads::DataManager::V1::AwsWrappedKeyInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::AwsWrappedKeyInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/encryption_info.rb
Overview
A data encryption key wrapped by an AWS KMS key.
Defined Under Namespace
Modules: KeyType
Instance Attribute Summary collapse
-
#encrypted_dek ⇒ ::String
Required.
-
#kek_uri ⇒ ::String
Required.
-
#key_type ⇒ ::Google::Ads::DataManager::V1::AwsWrappedKeyInfo::KeyType
Required.
-
#role_arn ⇒ ::String
Required.
Instance Attribute Details
#encrypted_dek ⇒ ::String
Returns Required. The base64 encoded encrypted data encryption key.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 92 class AwsWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#kek_uri ⇒ ::String
Returns Required. The URI of the AWS KMS key used to decrypt the DEK. Should be in
the format of arn:{partition}:kms:{region}:{account_id}:key/{key_id} or
aws-kms://arn:{partition}:kms:{region}:{account_id}:key/{key_id}.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 92 class AwsWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#key_type ⇒ ::Google::Ads::DataManager::V1::AwsWrappedKeyInfo::KeyType
Returns Required. The type of algorithm used to encrypt the data.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 92 class AwsWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#role_arn ⇒ ::String
Returns Required. The Amazon Resource Name of the IAM Role to assume for KMS
decryption access. Should be in the format of
arn:{partition}:iam::{account_id}:role/{role_name}.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 92 class AwsWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |