Class: Google::Ads::DataManager::V1::AwsWrappedKeyInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::AwsWrappedKeyInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/encryption_info.rb
Overview
A data encryption key wrapped by an AWS KMS key.
Defined Under Namespace
Modules: KeyType
Instance Attribute Summary collapse
-
#encrypted_dek ⇒ ::String
Required.
-
#kek_uri ⇒ ::String
Required.
-
#key_type ⇒ ::Google::Ads::DataManager::V1::AwsWrappedKeyInfo::KeyType
Required.
-
#role_arn ⇒ ::String
Required.
Instance Attribute Details
#encrypted_dek ⇒ ::String
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 89 class AwsWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#kek_uri ⇒ ::String
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 89 class AwsWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#key_type ⇒ ::Google::Ads::DataManager::V1::AwsWrappedKeyInfo::KeyType
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 89 class AwsWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#role_arn ⇒ ::String
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 89 class AwsWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |