Class: Google::Ads::DataManager::V1::CartData
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::CartData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/cart_data.rb
Overview
The cart data associated with the event.
Instance Attribute Summary collapse
-
#items ⇒ ::Array<::Google::Ads::DataManager::V1::Item>
Optional.
-
#merchant_feed_label ⇒ ::String
Optional.
-
#merchant_feed_language_code ⇒ ::String
Optional.
-
#merchant_id ⇒ ::String
Optional.
-
#transaction_discount ⇒ ::Float
Optional.
Instance Attribute Details
#items ⇒ ::Array<::Google::Ads::DataManager::V1::Item>
Returns Optional. The list of items associated with the event.
42 43 44 45 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 42 class CartData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#merchant_feed_label ⇒ ::String
Returns Optional. The Merchant Center feed label associated with the feed of the items.
42 43 44 45 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 42 class CartData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#merchant_feed_language_code ⇒ ::String
Returns Optional. The language code in ISO 639-1 associated with the Merchant Center feed of the items.where your items are uploaded.
42 43 44 45 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 42 class CartData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |