Class: Google::Ads::DataManager::V1::Destination
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::Destination
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/destination.rb
Overview
The Google product you're sending data to. For example, a Google Ads account.
Instance Attribute Summary collapse
-
#linked_account ⇒ ::Google::Ads::DataManager::V1::ProductAccount
Optional.
-
#login_account ⇒ ::Google::Ads::DataManager::V1::ProductAccount
Optional.
-
#operating_account ⇒ ::Google::Ads::DataManager::V1::ProductAccount
Required.
-
#product_destination_id ⇒ ::String
Required.
-
#reference ⇒ ::String
Optional.
Instance Attribute Details
#linked_account ⇒ ::Google::Ads::DataManager::V1::ProductAccount
Returns Optional. An account that the calling user's
login_account has
access to, through an established account link. For example, a data
partner's login_account might have access to a client's linked_account.
The partner might use this field to send data from the linked_account to
another
operating_account.
57 58 59 60 |
# File 'proto_docs/google/ads/datamanager/v1/destination.rb', line 57 class Destination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#login_account ⇒ ::Google::Ads::DataManager::V1::ProductAccount
Returns Optional. The account used to make this API call. To add or remove data
from the
operating_account,
this login_account must have write access to the operating_account. For
example, a manager account of the operating_account, or an account with
an established link to the operating_account.
57 58 59 60 |
# File 'proto_docs/google/ads/datamanager/v1/destination.rb', line 57 class Destination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#operating_account ⇒ ::Google::Ads::DataManager::V1::ProductAccount
Returns Required. The account to send the data to or remove the data from.
57 58 59 60 |
# File 'proto_docs/google/ads/datamanager/v1/destination.rb', line 57 class Destination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product_destination_id ⇒ ::String
Returns Required. The object within the product account to ingest into. For example, a Google Ads audience ID, a Display & Video 360 audience ID or a Google Ads conversion action ID.
57 58 59 60 |
# File 'proto_docs/google/ads/datamanager/v1/destination.rb', line 57 class Destination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#reference ⇒ ::String
Returns Optional. ID for this Destination resource, unique within the request.
Use to reference this Destination in the
IngestEventsRequest and
IngestAudienceMembersRequest.
57 58 59 60 |
# File 'proto_docs/google/ads/datamanager/v1/destination.rb', line 57 class Destination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |