Class: Google::Ads::DataManager::V1::DeviceInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::DeviceInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/device_info.rb
Overview
Information about the device being used (if any) when the event happened.
Instance Attribute Summary collapse
-
#ip_address ⇒ ::String
Optional.
-
#user_agent ⇒ ::String
Optional.
Instance Attribute Details
#ip_address ⇒ ::String
Returns Optional. The IP address of the device for the given context.
Note: Google Ads does not support IP address matching for end users in the European Economic Area (EEA), United Kingdom (UK), or Switzerland (CH). Add logic to conditionally exclude sharing IP addresses from users from these regions and ensure that you provide users with clear and comprehensive information about the data you collect on your sites, apps, and other properties and get consent where required by law or any applicable Google policies. See the About offline conversion imports page for more details.
41 42 43 44 |
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 41 class DeviceInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_agent ⇒ ::String
Returns Optional. The user-agent string of the device for the given context.
41 42 43 44 |
# File 'proto_docs/google/ads/datamanager/v1/device_info.rb', line 41 class DeviceInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |