Class: Google::Ads::DataManager::V1::EncryptedUserId
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::EncryptedUserId
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/encrypted_user_id.rb
Overview
A user identifier issued to be used for attribution. All fields are required if this is used.
Defined Under Namespace
Modules: EncryptionEntityType, EncryptionSource
Instance Attribute Summary collapse
-
#encrypted_id ⇒ ::String
Required.
-
#entity_id ⇒ ::Integer
Required.
-
#entity_type ⇒ ::Google::Ads::DataManager::V1::EncryptedUserId::EncryptionEntityType
Required.
-
#source ⇒ ::Google::Ads::DataManager::V1::EncryptedUserId::EncryptionSource
Required.
Instance Attribute Details
#encrypted_id ⇒ ::String
Returns Required. The alphanumeric encrypted id.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/ads/datamanager/v1/encrypted_user_id.rb', line 41 class EncryptedUserId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The encryption entity type. module EncryptionEntityType # Unspecified encryption entity type. ENCRYPTION_ENTITY_TYPE_UNSPECIFIED = 0 # Campaign Manager 360 account. CAMPAIGN_MANAGER_ACCOUNT = 1 # Campaign Manager 360 advertiser. CAMPAIGN_MANAGER_ADVERTISER = 2 # Display & Video 360 partner. DISPLAY_VIDEO_PARTNER = 3 # Display & Video 360 advertiser. DISPLAY_VIDEO_ADVERTISER = 4 # Google Ads customer. GOOGLE_ADS_CUSTOMER = 5 # Google Ad Manager network code. GOOGLE_AD_MANAGER_NETWORK_CODE = 6 end # The encryption source. module EncryptionSource # Unspecified encryption source. ENCRYPTION_SOURCE_UNSPECIFIED = 0 # Ad serving encryption source. AD_SERVING = 1 # Data transfer encryption source. DATA_TRANSFER = 2 end end |
#entity_id ⇒ ::Integer
Returns Required. The encryption entity ID. This should match the encryption configuration for ad serving or Data Transfer.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/ads/datamanager/v1/encrypted_user_id.rb', line 41 class EncryptedUserId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The encryption entity type. module EncryptionEntityType # Unspecified encryption entity type. ENCRYPTION_ENTITY_TYPE_UNSPECIFIED = 0 # Campaign Manager 360 account. CAMPAIGN_MANAGER_ACCOUNT = 1 # Campaign Manager 360 advertiser. CAMPAIGN_MANAGER_ADVERTISER = 2 # Display & Video 360 partner. DISPLAY_VIDEO_PARTNER = 3 # Display & Video 360 advertiser. DISPLAY_VIDEO_ADVERTISER = 4 # Google Ads customer. GOOGLE_ADS_CUSTOMER = 5 # Google Ad Manager network code. GOOGLE_AD_MANAGER_NETWORK_CODE = 6 end # The encryption source. module EncryptionSource # Unspecified encryption source. ENCRYPTION_SOURCE_UNSPECIFIED = 0 # Ad serving encryption source. AD_SERVING = 1 # Data transfer encryption source. DATA_TRANSFER = 2 end end |
#entity_type ⇒ ::Google::Ads::DataManager::V1::EncryptedUserId::EncryptionEntityType
Returns Required. The encryption entity type. This should match the encryption configuration for ad serving or Data Transfer.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/ads/datamanager/v1/encrypted_user_id.rb', line 41 class EncryptedUserId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The encryption entity type. module EncryptionEntityType # Unspecified encryption entity type. ENCRYPTION_ENTITY_TYPE_UNSPECIFIED = 0 # Campaign Manager 360 account. CAMPAIGN_MANAGER_ACCOUNT = 1 # Campaign Manager 360 advertiser. CAMPAIGN_MANAGER_ADVERTISER = 2 # Display & Video 360 partner. DISPLAY_VIDEO_PARTNER = 3 # Display & Video 360 advertiser. DISPLAY_VIDEO_ADVERTISER = 4 # Google Ads customer. GOOGLE_ADS_CUSTOMER = 5 # Google Ad Manager network code. GOOGLE_AD_MANAGER_NETWORK_CODE = 6 end # The encryption source. module EncryptionSource # Unspecified encryption source. ENCRYPTION_SOURCE_UNSPECIFIED = 0 # Ad serving encryption source. AD_SERVING = 1 # Data transfer encryption source. DATA_TRANSFER = 2 end end |
#source ⇒ ::Google::Ads::DataManager::V1::EncryptedUserId::EncryptionSource
Returns Required. Describes whether the encrypted cookie was received from ad serving (the %m macro) or from Data Transfer.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/ads/datamanager/v1/encrypted_user_id.rb', line 41 class EncryptedUserId include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The encryption entity type. module EncryptionEntityType # Unspecified encryption entity type. ENCRYPTION_ENTITY_TYPE_UNSPECIFIED = 0 # Campaign Manager 360 account. CAMPAIGN_MANAGER_ACCOUNT = 1 # Campaign Manager 360 advertiser. CAMPAIGN_MANAGER_ADVERTISER = 2 # Display & Video 360 partner. DISPLAY_VIDEO_PARTNER = 3 # Display & Video 360 advertiser. DISPLAY_VIDEO_ADVERTISER = 4 # Google Ads customer. GOOGLE_ADS_CUSTOMER = 5 # Google Ad Manager network code. GOOGLE_AD_MANAGER_NETWORK_CODE = 6 end # The encryption source. module EncryptionSource # Unspecified encryption source. ENCRYPTION_SOURCE_UNSPECIFIED = 0 # Ad serving encryption source. AD_SERVING = 1 # Data transfer encryption source. DATA_TRANSFER = 2 end end |