Class: Google::Ads::DataManager::V1::ErrorCount
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::ErrorCount
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/processing_errors.rb
Overview
The error count for a given error reason.
Instance Attribute Summary collapse
-
#reason ⇒ ::Google::Ads::DataManager::V1::ProcessingErrorReason
The error reason of the failed records.
-
#record_count ⇒ ::Integer
The count of records that failed to upload for a given reason.
Instance Attribute Details
#reason ⇒ ::Google::Ads::DataManager::V1::ProcessingErrorReason
Returns The error reason of the failed records.
41 42 43 44 |
# File 'proto_docs/google/ads/datamanager/v1/processing_errors.rb', line 41 class ErrorCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#record_count ⇒ ::Integer
Returns The count of records that failed to upload for a given reason.
41 42 43 44 |
# File 'proto_docs/google/ads/datamanager/v1/processing_errors.rb', line 41 class ErrorCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |