Module: Google::Ads::DataManager::V1::ErrorReason
- Defined in:
- proto_docs/google/ads/datamanager/v1/error.rb
Overview
Error reasons for Data Manager API. NOTE: This enum is not frozen and new values may be added in the future.
Constant Summary collapse
- ERROR_REASON_UNSPECIFIED =
Do not use this default value.
0- INTERNAL_ERROR =
An internal error has occurred.
1- DEADLINE_EXCEEDED =
The request took too long to respond.
2- RESOURCE_EXHAUSTED =
Too many requests.
3- NOT_FOUND =
Resource not found.
4- PERMISSION_DENIED =
The user does not have permission or the resource is not found.
5- INVALID_ARGUMENT =
There was a problem with the request.
6- REQUIRED_FIELD_MISSING =
Required field is missing.
7- INVALID_FORMAT =
Format is invalid.
8- INVALID_HEX_ENCODING =
The HEX encoded value is malformed.
9- INVALID_BASE64_ENCODING =
The base64 encoded value is malformed.
10- INVALID_SHA256_FORMAT =
The SHA256 encoded value is malformed.
11- INVALID_POSTAL_CODE =
Postal code is not valid.
12- INVALID_COUNTRY_CODE =
Deprecated: Enum is unused in the Data Manager API.
13- INVALID_ENUM_VALUE =
Enum value cannot be used.
14- INVALID_USER_LIST_TYPE =
Type of the user list is not applicable for this request.
15- INVALID_AUDIENCE_MEMBER =
This audience member is not valid.
16- TOO_MANY_AUDIENCE_MEMBERS =
Maximum number of audience members allowed per request is 10,000.
17- TOO_MANY_USER_IDENTIFIERS =
Maximum number of user identifiers allowed per audience member is 10.
18- TOO_MANY_DESTINATIONS =
Maximum number of destinations allowed per request is 10.
19- INVALID_DESTINATION =
This Destination is not valid.
20- DATA_PARTNER_USER_LIST_MUTATE_NOT_ALLOWED =
Data Partner does not have access to the operating account owned userlist.
21- INVALID_MOBILE_ID_FORMAT =
Mobile ID format is not valid.
22- INVALID_USER_LIST_ID =
User list is not valid.
23- MULTIPLE_DATA_TYPES_NOT_ALLOWED =
Multiple data types are not allowed to be ingested in a single request.
24- DIFFERENT_LOGIN_ACCOUNTS_NOT_ALLOWED_FOR_DATA_PARTNER =
Destination configs containing a DataPartner login account must have the same login account across all destination configs.
25- TERMS_AND_CONDITIONS_NOT_SIGNED =
Required terms and conditions are not accepted.
26- INVALID_NUMBER_FORMAT =
Invalid number format.
27- INVALID_CONVERSION_ACTION_ID =
Conversion action ID is not valid.
28- INVALID_CONVERSION_ACTION_TYPE =
The conversion action type is not valid.
29- INVALID_CURRENCY_CODE =
The currency code is not supported.
30- INVALID_EVENT =
This event is not valid.
31- TOO_MANY_EVENTS =
Maximum number of events allowed per request is 10,000.
32- DESTINATION_ACCOUNT_NOT_ENABLED_ENHANCED_CONVERSIONS_FOR_LEADS =
The destination account is not enabled for enhanced conversions for leads.
33- DESTINATION_ACCOUNT_DATA_POLICY_PROHIBITS_ENHANCED_CONVERSIONS =
Enhanced conversions can't be used for the destination account because of Google customer data policies. Contact your Google representative..
34- DESTINATION_ACCOUNT_ENHANCED_CONVERSIONS_TERMS_NOT_SIGNED =
The destination account hasn't agreed to the terms for enhanced conversions.
35- DUPLICATE_DESTINATION_REFERENCE =
Two or more destinations in the request have the same reference.
36- UNSUPPORTED_OPERATING_ACCOUNT_FOR_DATA_PARTNER =
Unsupported operating account for data partner authorization.
37- UNSUPPORTED_LINKED_ACCOUNT_FOR_DATA_PARTNER =
Unsupported linked account for data partner authorization.
38- NO_IDENTIFIERS_PROVIDED =
Events data contains no user identifiers or ad identifiers.
39- INVALID_PROPERTY_TYPE =
The property type is not supported.
40- INVALID_STREAM_TYPE =
The stream type is not supported.
41- LINKED_ACCOUNT_ONLY_ALLOWED_WITH_DATA_PARTNER_LOGIN_ACCOUNT =
Linked account is only supported when the login account is a
DATA_PARTNERaccount. 42- OPERATING_ACCOUNT_LOGIN_ACCOUNT_MISMATCH =
The login account must be the same as the operating account for the given use case.
43- EVENT_TIME_INVALID =
Event did not occur within the acceptable time window.
44- RESERVED_NAME_USED =
Parameter uses a reserved name.
45- INVALID_EVENT_NAME =
The event name is not supported.
46- NOT_ALLOWLISTED =
The account is not allowlisted for the given feature.
47- INVALID_REQUEST_ID =
The request ID used to retrieve the status of a request is not valid. Status can only be retrieved for requests that succeed and don't have
validate_only=true. 48- MULTIPLE_DESTINATIONS_FOR_GOOGLE_ANALYTICS_EVENT =
An event had 2 or more Google Analytics destinations.
49- FIELD_VALUE_TOO_LONG =
The field value is too long.
50- TOO_MANY_ELEMENTS =
Too many elements in a list in the request.
51- ALREADY_EXISTS =
The resource already exists.
52- IMMUTABLE_FIELD_FOR_UPDATE =
Attempted to set an immutable field for an update request.
53- INVALID_RESOURCE_NAME =
The resource name is invalid.
54- INVALID_FILTER =
The query filter is invalid.
55- INVALID_UPDATE_MASK =
The update mask is invalid.
56- INVALID_PAGE_TOKEN =
The page token is invalid.
57- CANNOT_UPDATE_DISABLED_LICENSE =
Cannot update a license that has been disabled.
58- CANNOT_CREATE_LICENSE_FOR_SENSITIVE_USERLIST =
Sensitive user lists cannot be licensed to this client.
59- INSUFFICIENT_COST =
Cost too low for this license.
60- CANNOT_DISABLE_LICENSE =
Reseller license cannot be disabled since it is in use.
61- INVALID_CLIENT_ACCOUNT_ID =
Invalid client account id.
62- PRICING_ONLY_ZERO_COST_ALLOWED =
Non-zero cost not allowed for this client account.
63- PRICE_TOO_HIGH =
Cost too high for this license.
64- CUSTOMER_NOT_ALLOWED_TO_CREATE_LICENSE =
Customer not allowed to create license.
65- INVALID_PRICING_END_DATE =
Pricing end date is invalid for this license.
66- CANNOT_LICENSE_LOGICAL_LIST_WITH_LICENSED_OR_SHARED_SEGMENT =
Logical user list with shared or licensed segment cannot be licensed.
67- MISMATCHED_ACCOUNT_TYPE =
Client customer's account type in the request does not match the customer's actual account type.
68- MEDIA_SHARE_COST_NOT_ALLOWED_FOR_LICENSE_TYPE =
License type does not support media share cost.
69- MEDIA_SHARE_COST_NOT_ALLOWED_FOR_CLIENT_CUSTOMER =
Client customer type does not support media share cost.
70- INVALID_MEDIA_SHARE_COST =
Invalid media share cost.
71- INVALID_COST_TYPE =
Invalid cost type.
72- MEDIA_SHARE_COST_NOT_ALLOWED_FOR_NON_COMMERCE_USER_LIST =
UserList type does not support media share cost.
73- MAX_COST_NOT_ALLOWED =
Max cost is only allowed for cost_type MEDIA_SHARE.
74- COMMERCE_AUDIENCE_CAN_ONLY_BE_DIRECTLY_LICENSED =
Commerce audience can only be directly licensed.
75- INVALID_DESCRIPTION =
The description is not valid.
76- INVALID_DISPLAY_NAME =
The display name is not valid.
77- DISPLAY_NAME_ALREADY_USED =
The display name is already being used for another user list for the account.
78- OWNERSHIP_REQUIRED_FOR_UPDATE =
Ownership is required to modify the user list.
79- USER_LIST_MUTATION_NOT_SUPPORTED =
The user list type is read-only and does not support mutation.
80- SENSITIVE_USER_LIST_IMMUTABLE =
A user list which is privacy sensitive or legal rejected cannot be mutated by external users.
81- BILLABLE_RECORD_COUNT_IMMUTABLE =
The remarketing user list's billable record field cannot be modified once it is set.
82- USER_LIST_NAME_RESERVED =
The user list name is reserved for system lists.
83- ADVERTISER_NOT_ALLOWLISTED_FOR_UPLOADED_DATA =
The advertiser needs to be allowlisted to use remarketing lists created from advertiser uploaded data.
84- UNSUPPORTED_PARTNER_AUDIENCE_SOURCE =
The partner audience source is not supported for the user list type.
85- COMMERCE_PARTNER_NOT_ALLOWED =
Setting the
commerce_partnerfield is only supported if thepartner_audience_sourceisCOMMERCE_AUDIENCE. 86- UNSUPPORTED_PARTNER_AUDIENCE_INFO =
The
partner_audience_infofield is not supported for the user list type. 87- PARTNER_MATCH_FOR_MANAGER_ACCOUNT_DISALLOWED =
Partner Match user lists cannot be created by manager accounts.
88- DATA_PARTNER_NOT_ALLOWLISTED_FOR_THIRD_PARTY_PARTNER_DATA =
The data partner is not allowlisted for THIRD_PARTY_PARTNER_DATA.
89- ADVERTISER_TOS_NOT_ACCEPTED =
The advertiser has not accepted the partner's terms of service.
90- ADVERTISER_NOT_ALLOWLISTED_FOR_THIRD_PARTY_PARTNER_DATA =
The advertiser is not allowlisted for THIRD_PARTY_PARTNER_DATA.
91- USER_LIST_TYPE_NOT_SUPPORTED_FOR_ACCOUNT =
This user list type is not supported for this account.
92- INVALID_COMMERCE_PARTNER =
The
commerce_partnerfield is invalid. 93- CUSTOMER_NOT_ALLOWLISTED_FOR_COMMERCE_AUDIENCE =
The data provider is not allowlisted to create commerce audiences.
94- UNSUPPORTED_USER_LIST_UPLOAD_KEY_TYPES =
The user list upload key types are not supported.
95- UNSUPPORTED_INGESTED_USER_LIST_INFO_CONFIG =
The ingested user list info config is not supported.
96- UNSUPPORTED_ACCOUNT_TYPES_FOR_USER_LIST_TYPE =
The account types are not supported for the user list type.
97- UNSUPPORTED_ACCOUNT_TYPE_FOR_PARTNER_LINK =
The account types are not supported for the partner link.
98- MEMBERSHIP_DURATION_TOO_LONG =
The user list membership duration is too long.
99- INVALID_MERCHANT_ID =
The
merchant_idfield is not valid. 100- EU_POLITICAL_ADVERTISING_DECLARATION_REQUIRED =
The customer contains non-exempt campaigns without the EU political advertising declaration.
101