Module: Google::Ads::DataManager::V1::ErrorReason
- Defined in:
- proto_docs/google/ads/datamanager/v1/error.rb
Overview
Error reasons for Data Manager API.
Constant Summary collapse
- ERROR_REASON_UNSPECIFIED =
Do not use this default value.
0- INTERNAL_ERROR =
An internal error has occurred.
1- DEADLINE_EXCEEDED =
The request took too long to respond.
2- RESOURCE_EXHAUSTED =
Too many requests.
3- NOT_FOUND =
Resource not found.
4- PERMISSION_DENIED =
The user does not have permission or the resource is not found.
5- INVALID_ARGUMENT =
There was a problem with the request.
6- REQUIRED_FIELD_MISSING =
Required field is missing.
7- INVALID_FORMAT =
Format is invalid.
8- INVALID_HEX_ENCODING =
The HEX encoded value is malformed.
9- INVALID_BASE64_ENCODING =
The base64 encoded value is malformed.
10- INVALID_SHA256_FORMAT =
The SHA256 encoded value is malformed.
11- INVALID_POSTAL_CODE =
Postal code is not valid.
12- INVALID_COUNTRY_CODE =
Country code is not valid.
13- INVALID_ENUM_VALUE =
Enum value cannot be used.
14- INVALID_USER_LIST_TYPE =
Type of the user list is not applicable for this request.
15- INVALID_AUDIENCE_MEMBER =
This audience member is not valid.
16- TOO_MANY_AUDIENCE_MEMBERS =
Maximum number of audience members allowed per request is 10,000.
17- TOO_MANY_USER_IDENTIFIERS =
Maximum number of user identifiers allowed per audience member is 10.
18- TOO_MANY_DESTINATIONS =
Maximum number of destinations allowed per request is 10.
19- INVALID_DESTINATION =
This Destination is not valid.
20- DATA_PARTNER_USER_LIST_MUTATE_NOT_ALLOWED =
Data Partner does not have access to the operating account owned userlist.
21- INVALID_MOBILE_ID_FORMAT =
Mobile ID format is not valid.
22- INVALID_USER_LIST_ID =
User list is not valid.
23- MULTIPLE_DATA_TYPES_NOT_ALLOWED =
Multiple data types are not allowed to be ingested in a single request.
24- DIFFERENT_LOGIN_ACCOUNTS_NOT_ALLOWED_FOR_DATA_PARTNER =
Destination configs containing a DataPartner login account must have the same login account across all destination configs.
25- TERMS_AND_CONDITIONS_NOT_SIGNED =
Required terms and conditions are not accepted.
26- INVALID_NUMBER_FORMAT =
Invalid number format.
27- INVALID_CONVERSION_ACTION_ID =
Conversion action ID is not valid.
28- INVALID_CONVERSION_ACTION_TYPE =
The conversion action type is not valid.
29- INVALID_CURRENCY_CODE =
The currency code is not supported.
30- INVALID_EVENT =
This event is not valid.
31- TOO_MANY_EVENTS =
Maximum number of events allowed per request is 10,000.
32- DESTINATION_ACCOUNT_NOT_ENABLED_ENHANCED_CONVERSIONS_FOR_LEADS =
The destination account is not enabled for enhanced conversions for leads.
33- DESTINATION_ACCOUNT_DATA_POLICY_PROHIBITS_ENHANCED_CONVERSIONS =
Enhanced conversions can't be used for the destination account because of Google customer data policies. Contact your Google representative..
34- DESTINATION_ACCOUNT_ENHANCED_CONVERSIONS_TERMS_NOT_SIGNED =
The destination account hasn't agreed to the terms for enhanced conversions.
35- DUPLICATE_DESTINATION_REFERENCE =
Two or more destinations in the request have the same reference.
36- UNSUPPORTED_OPERATING_ACCOUNT_FOR_DATA_PARTNER =
Unsupported operating account for data partner authorization.
37- UNSUPPORTED_LINKED_ACCOUNT_FOR_DATA_PARTNER =
Unsupported linked account for data partner authorization.
38- NO_IDENTIFIERS_PROVIDED =
Events data contains no user identifiers or ad identifiers.
39- INVALID_PROPERTY_TYPE =
The property type is not supported.
40- INVALID_STREAM_TYPE =
The stream type is not supported.
41- LINKED_ACCOUNT_ONLY_ALLOWED_WITH_DATA_PARTNER_LOGIN_ACCOUNT =
Linked account is only supported when the login account is a
DATA_PARTNERaccount. 42- OPERATING_ACCOUNT_LOGIN_ACCOUNT_MISMATCH =
The login account must be the same as the operating account for the given use case.
43- EVENT_TIME_INVALID =
Event did not occur within the acceptable time window.
44- RESERVED_NAME_USED =
Parameter uses a reserved name.
45- INVALID_EVENT_NAME =
The event name is not supported.
46- NOT_ALLOWLISTED =
The account is not allowlisted for the given feature.
47- INVALID_REQUEST_ID =
The request ID used to retrieve the status of a request is not valid. Status can only be retrieved for requests that succeed and don't have
validate_only=true. 48- MULTIPLE_DESTINATIONS_FOR_GOOGLE_ANALYTICS_EVENT =
An event had 2 or more Google Analytics destinations.
49- FIELD_VALUE_TOO_LONG =
The field value is too long.
50- TOO_MANY_ELEMENTS =
Too many elements in a list in the request.
51