Class: Google::Ads::DataManager::V1::Event
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::Event
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/event.rb
Overview
An event representing a user interaction with an advertiser's website or app.
Instance Attribute Summary collapse
-
#ad_identifiers ⇒ ::Google::Ads::DataManager::V1::AdIdentifiers
Optional.
-
#additional_event_parameters ⇒ ::Array<::Google::Ads::DataManager::V1::EventParameter>
Optional.
-
#cart_data ⇒ ::Google::Ads::DataManager::V1::CartData
Optional.
-
#client_id ⇒ ::String
Optional.
-
#consent ⇒ ::Google::Ads::DataManager::V1::Consent
Optional.
-
#conversion_value ⇒ ::Float
Optional.
-
#currency ⇒ ::String
Optional.
-
#custom_variables ⇒ ::Array<::Google::Ads::DataManager::V1::CustomVariable>
Optional.
-
#destination_references ⇒ ::Array<::String>
Optional.
-
#event_device_info ⇒ ::Google::Ads::DataManager::V1::DeviceInfo
Optional.
-
#event_name ⇒ ::String
Optional.
-
#event_source ⇒ ::Google::Ads::DataManager::V1::EventSource
Optional.
-
#event_timestamp ⇒ ::Google::Protobuf::Timestamp
Required.
-
#experimental_fields ⇒ ::Array<::Google::Ads::DataManager::V1::ExperimentalField>
Optional.
-
#last_updated_timestamp ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#transaction_id ⇒ ::String
Optional.
-
#user_data ⇒ ::Google::Ads::DataManager::V1::UserData
Optional.
-
#user_id ⇒ ::String
Optional.
-
#user_properties ⇒ ::Google::Ads::DataManager::V1::UserProperties
Optional.
Instance Attribute Details
#ad_identifiers ⇒ ::Google::Ads::DataManager::V1::AdIdentifiers
Returns Optional. Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#additional_event_parameters ⇒ ::Array<::Google::Ads::DataManager::V1::EventParameter>
Returns Optional. A bucket of any event parameters to be included within the event that were not already specified using other structured fields.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cart_data ⇒ ::Google::Ads::DataManager::V1::CartData
Returns Optional. Information about the transaction and items associated with the event.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_id ⇒ ::String
Returns Optional. A unique identifier for the user instance of a web client for this GA4 web stream.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#consent ⇒ ::Google::Ads::DataManager::V1::Consent
Returns Optional. Information about whether the associated user has provided different types of consent.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#conversion_value ⇒ ::Float
Returns Optional. The conversion value associated with the event, for value-based conversions.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#currency ⇒ ::String
Returns Optional. The currency code associated with all monetary values within this event.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_variables ⇒ ::Array<::Google::Ads::DataManager::V1::CustomVariable>
Returns Optional. Additional key/value pair information to send to the conversion containers (conversion action or FL activity).
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#destination_references ⇒ ::Array<::String>
Returns Optional. Reference string used to determine the destination. If empty, the event will be sent to all destinations in the request.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#event_device_info ⇒ ::Google::Ads::DataManager::V1::DeviceInfo
Returns Optional. Information gathered about the device being used (if any) when the event happened.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#event_name ⇒ ::String
Returns Optional. The name of the event. Required for GA4 events.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#event_source ⇒ ::Google::Ads::DataManager::V1::EventSource
Returns Optional. Signal for where the event happened (web, app, in-store, etc.).
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#event_timestamp ⇒ ::Google::Protobuf::Timestamp
Returns Required. The time the event occurred.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#experimental_fields ⇒ ::Array<::Google::Ads::DataManager::V1::ExperimentalField>
Returns Optional. A list of key/value pairs for experimental fields that may eventually be promoted to be part of the API.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_updated_timestamp ⇒ ::Google::Protobuf::Timestamp
Returns Optional. The last time the event was updated.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transaction_id ⇒ ::String
Returns Optional. The unique identifier for this event. Required for conversions using multiple data sources.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_data ⇒ ::Google::Ads::DataManager::V1::UserData
Returns Optional. Pieces of user provided data, representing the user the event is associated with.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_id ⇒ ::String
Returns Optional. A unique identifier for a user, as defined by the advertiser.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_properties ⇒ ::Google::Ads::DataManager::V1::UserProperties
Returns Optional. Advertiser-assessed information about the user at the time that the event happened.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 100 class Event include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |