Class: Google::Ads::DataManager::V1::EventLocation
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::EventLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/event.rb
Overview
The location where the event occurred.
Instance Attribute Summary collapse
-
#city ⇒ ::String
Optional.
-
#continent_code ⇒ ::String
Optional.
-
#region_code ⇒ ::String
Optional.
-
#store_id ⇒ ::String
Optional.
-
#subcontinent_code ⇒ ::String
Optional.
-
#subdivision_code ⇒ ::String
Optional.
Instance Attribute Details
#city ⇒ ::String
Returns Optional. The name of the city where the event occurred.
199 200 201 202 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 199 class EventLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#continent_code ⇒ ::String
Returns Optional. The continent code in UN M49 format where the event occurred.
199 200 201 202 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 199 class EventLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region_code ⇒ ::String
Returns Optional. The 2-letter CLDR region code of the user's address.
199 200 201 202 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 199 class EventLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#store_id ⇒ ::String
Returns Optional. Required for Store Sales. The identifier to represent a physical store where the event happened.
199 200 201 202 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 199 class EventLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subcontinent_code ⇒ ::String
Returns Optional. The subcontinent code in UN M49 format where the event occurred.
199 200 201 202 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 199 class EventLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#subdivision_code ⇒ ::String
Returns Optional. The ISO 3166-2 subdivision code where the event occurred.
199 200 201 202 |
# File 'proto_docs/google/ads/datamanager/v1/event.rb', line 199 class EventLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |