Class: Google::Ads::DataManager::V1::GcpWrappedKeyInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::GcpWrappedKeyInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/encryption_info.rb
Overview
Information about the Google Cloud Platform wrapped key.
Defined Under Namespace
Modules: KeyType
Instance Attribute Summary collapse
-
#encrypted_dek ⇒ ::String
Required.
-
#kek_uri ⇒ ::String
Required.
-
#key_type ⇒ ::Google::Ads::DataManager::V1::GcpWrappedKeyInfo::KeyType
Required.
-
#wip_provider ⇒ ::String
Required.
Instance Attribute Details
#encrypted_dek ⇒ ::String
Returns Required. The base64 encoded encrypted data encryption key.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 61 class GcpWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#kek_uri ⇒ ::String
Returns Required. Google Cloud Platform Cloud Key Management Service resource
ID. Should be in the
format of
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{key}
or
gcp-kms://projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{key}.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 61 class GcpWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#key_type ⇒ ::Google::Ads::DataManager::V1::GcpWrappedKeyInfo::KeyType
Returns Required. The type of algorithm used to encrypt the data.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 61 class GcpWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |
#wip_provider ⇒ ::String
Returns Required. The Workload Identity pool provider required to use KEK.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'proto_docs/google/ads/datamanager/v1/encryption_info.rb', line 61 class GcpWrappedKeyInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of algorithm used to encrypt the data. module KeyType # Unspecified key type. Should never be used. KEY_TYPE_UNSPECIFIED = 0 # Algorithm XChaCha20-Poly1305 XCHACHA20_POLY1305 = 1 end end |