Class: Google::Ads::DataManager::V1::IngestedUserListInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::IngestedUserListInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list.rb
Overview
Represents a user list that is populated by user provided data.
Defined Under Namespace
Modules: UploadKeyType
Instance Attribute Summary collapse
-
#contact_id_info ⇒ ::Google::Ads::DataManager::V1::ContactIdInfo
Optional.
-
#mobile_id_info ⇒ ::Google::Ads::DataManager::V1::MobileIdInfo
Optional.
-
#pair_id_info ⇒ ::Google::Ads::DataManager::V1::PairIdInfo
Optional.
-
#partner_audience_info ⇒ ::Google::Ads::DataManager::V1::PartnerAudienceInfo
Optional.
-
#pseudonymous_id_info ⇒ ::Google::Ads::DataManager::V1::PseudonymousIdInfo
Optional.
-
#upload_key_types ⇒ ::Array<::Google::Ads::DataManager::V1::IngestedUserListInfo::UploadKeyType>
Required.
-
#user_id_info ⇒ ::Google::Ads::DataManager::V1::UserIdInfo
Optional.
Instance Attribute Details
#contact_id_info ⇒ ::Google::Ads::DataManager::V1::ContactIdInfo
Returns Optional. Additional information when CONTACT_ID is one of the
upload_key_types.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 198 class IngestedUserListInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum containing the possible upload key types of a user list. module UploadKeyType # Not specified. UPLOAD_KEY_TYPE_UNSPECIFIED = 0 # Customer info such as email address, phone number or physical address. CONTACT_ID = 1 # Mobile advertising ids. MOBILE_ID = 2 # Third party provided user ids. USER_ID = 3 # Publisher advertiser identity reconciliation ids. PAIR_ID = 4 # Data Management Platform IDs: # - Google User ID # - Partner Provided ID # - Publisher Provided ID # - iOS IDFA # - Android advertising ID # - Roku ID # - Amazon Fire TV ID # - Xbox or Microsoft ID PSEUDONYMOUS_ID = 5 end end |
#mobile_id_info ⇒ ::Google::Ads::DataManager::V1::MobileIdInfo
Returns Optional. Additional information when MOBILE_ID is one of the
upload_key_types.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 198 class IngestedUserListInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum containing the possible upload key types of a user list. module UploadKeyType # Not specified. UPLOAD_KEY_TYPE_UNSPECIFIED = 0 # Customer info such as email address, phone number or physical address. CONTACT_ID = 1 # Mobile advertising ids. MOBILE_ID = 2 # Third party provided user ids. USER_ID = 3 # Publisher advertiser identity reconciliation ids. PAIR_ID = 4 # Data Management Platform IDs: # - Google User ID # - Partner Provided ID # - Publisher Provided ID # - iOS IDFA # - Android advertising ID # - Roku ID # - Amazon Fire TV ID # - Xbox or Microsoft ID PSEUDONYMOUS_ID = 5 end end |
#pair_id_info ⇒ ::Google::Ads::DataManager::V1::PairIdInfo
Returns Optional. Additional information when PAIR_ID is one of the
upload_key_types.
This feature is only available to data partners.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 198 class IngestedUserListInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum containing the possible upload key types of a user list. module UploadKeyType # Not specified. UPLOAD_KEY_TYPE_UNSPECIFIED = 0 # Customer info such as email address, phone number or physical address. CONTACT_ID = 1 # Mobile advertising ids. MOBILE_ID = 2 # Third party provided user ids. USER_ID = 3 # Publisher advertiser identity reconciliation ids. PAIR_ID = 4 # Data Management Platform IDs: # - Google User ID # - Partner Provided ID # - Publisher Provided ID # - iOS IDFA # - Android advertising ID # - Roku ID # - Amazon Fire TV ID # - Xbox or Microsoft ID PSEUDONYMOUS_ID = 5 end end |
#partner_audience_info ⇒ ::Google::Ads::DataManager::V1::PartnerAudienceInfo
Returns Optional. Additional information for partner audiences.
This feature is only available to data partners.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 198 class IngestedUserListInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum containing the possible upload key types of a user list. module UploadKeyType # Not specified. UPLOAD_KEY_TYPE_UNSPECIFIED = 0 # Customer info such as email address, phone number or physical address. CONTACT_ID = 1 # Mobile advertising ids. MOBILE_ID = 2 # Third party provided user ids. USER_ID = 3 # Publisher advertiser identity reconciliation ids. PAIR_ID = 4 # Data Management Platform IDs: # - Google User ID # - Partner Provided ID # - Publisher Provided ID # - iOS IDFA # - Android advertising ID # - Roku ID # - Amazon Fire TV ID # - Xbox or Microsoft ID PSEUDONYMOUS_ID = 5 end end |
#pseudonymous_id_info ⇒ ::Google::Ads::DataManager::V1::PseudonymousIdInfo
Returns Optional. Additional information for PSEUDONYMOUS_ID is one of the
upload_key_types.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 198 class IngestedUserListInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum containing the possible upload key types of a user list. module UploadKeyType # Not specified. UPLOAD_KEY_TYPE_UNSPECIFIED = 0 # Customer info such as email address, phone number or physical address. CONTACT_ID = 1 # Mobile advertising ids. MOBILE_ID = 2 # Third party provided user ids. USER_ID = 3 # Publisher advertiser identity reconciliation ids. PAIR_ID = 4 # Data Management Platform IDs: # - Google User ID # - Partner Provided ID # - Publisher Provided ID # - iOS IDFA # - Android advertising ID # - Roku ID # - Amazon Fire TV ID # - Xbox or Microsoft ID PSEUDONYMOUS_ID = 5 end end |
#upload_key_types ⇒ ::Array<::Google::Ads::DataManager::V1::IngestedUserListInfo::UploadKeyType>
Returns Required. Immutable. Upload key types of this user list.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 198 class IngestedUserListInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum containing the possible upload key types of a user list. module UploadKeyType # Not specified. UPLOAD_KEY_TYPE_UNSPECIFIED = 0 # Customer info such as email address, phone number or physical address. CONTACT_ID = 1 # Mobile advertising ids. MOBILE_ID = 2 # Third party provided user ids. USER_ID = 3 # Publisher advertiser identity reconciliation ids. PAIR_ID = 4 # Data Management Platform IDs: # - Google User ID # - Partner Provided ID # - Publisher Provided ID # - iOS IDFA # - Android advertising ID # - Roku ID # - Amazon Fire TV ID # - Xbox or Microsoft ID PSEUDONYMOUS_ID = 5 end end |
#user_id_info ⇒ ::Google::Ads::DataManager::V1::UserIdInfo
Returns Optional. Additional information when USER_ID is one of the
upload_key_types.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 198 class IngestedUserListInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum containing the possible upload key types of a user list. module UploadKeyType # Not specified. UPLOAD_KEY_TYPE_UNSPECIFIED = 0 # Customer info such as email address, phone number or physical address. CONTACT_ID = 1 # Mobile advertising ids. MOBILE_ID = 2 # Third party provided user ids. USER_ID = 3 # Publisher advertiser identity reconciliation ids. PAIR_ID = 4 # Data Management Platform IDs: # - Google User ID # - Partner Provided ID # - Publisher Provided ID # - iOS IDFA # - Android advertising ID # - Roku ID # - Amazon Fire TV ID # - Xbox or Microsoft ID PSEUDONYMOUS_ID = 5 end end |