Class: Google::Ads::DataManager::V1::Item
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::Item
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/cart_data.rb
Overview
Represents an item in the cart associated with the event.
Instance Attribute Summary collapse
-
#additional_item_parameters ⇒ ::Array<::Google::Ads::DataManager::V1::ItemParameter>
Optional.
-
#item_id ⇒ ::String
Optional.
-
#merchant_product_id ⇒ ::String
Optional.
-
#quantity ⇒ ::Integer
Optional.
-
#unit_price ⇒ ::Float
Optional.
Instance Attribute Details
#additional_item_parameters ⇒ ::Array<::Google::Ads::DataManager::V1::ItemParameter>
Returns Optional. A bucket of any event parameters related to an item to be included within the event that were not already specified using other structured fields.
67 68 69 70 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 67 class Item include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#item_id ⇒ ::String
Returns Optional. A unique identifier to reference the item.
67 68 69 70 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 67 class Item include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#merchant_product_id ⇒ ::String
Returns Optional. The product ID within the Merchant Center account.
67 68 69 70 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 67 class Item include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#quantity ⇒ ::Integer
Returns Optional. The number of this item associated with the event.
67 68 69 70 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 67 class Item include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unit_price ⇒ ::Float
Returns Optional. The unit price excluding tax, shipping, and any transaction level discounts.
67 68 69 70 |
# File 'proto_docs/google/ads/datamanager/v1/cart_data.rb', line 67 class Item include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |