Class: Google::Ads::DataManager::V1::ListUserListGlobalLicensesRequest
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::ListUserListGlobalLicensesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb
Overview
Request to list all UserListGlobalLicense resources for a given account.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. A filter string to apply to the
list request. All fields need to be on the left hand side of each condition
(for example: user_list_id = 123). Fields must be specified using either
all camel case or all snake
case. Don't use a combination of
camel case and snake case.
Supported Operations:
AND=!=>>=<<=
Unsupported Fields:
name(use get method instead)historical_pricingsand all its subfieldspricing.start_timepricing.end_time.
113 114 115 116 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 113 class ListUserListGlobalLicensesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Optional. The maximum number of licenses to return. The service may return fewer than this value. If unspecified, at most 50 licenses will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
113 114 115 116 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 113 class ListUserListGlobalLicensesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous
ListUserListGlobalLicense call. Provide this to retrieve the subsequent
page.
When paginating, all other parameters provided to
ListUserListDirectLicense must match the call that provided the page
token.
113 114 115 116 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 113 class ListUserListGlobalLicensesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The account whose licenses are being queried. Should be in the format accountTypes/{ACCOUNT_TYPE}/accounts/{ACCOUNT_ID}.
113 114 115 116 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_global_license_service.rb', line 113 class ListUserListGlobalLicensesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |