Class: Google::Ads::DataManager::V1::PairIdInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::PairIdInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list.rb
Overview
Additional information when PAIR_ID is one of the upload_key_types.
This feature is only available to data partners.
Instance Attribute Summary collapse
-
#advertiser_identifier_count ⇒ ::Integer
Optional.
-
#clean_room_identifier ⇒ ::String
Required.
-
#match_rate_percentage ⇒ ::Integer
Required.
-
#publisher_id ⇒ ::Integer
Required.
-
#publisher_name ⇒ ::String
Required.
Instance Attribute Details
#advertiser_identifier_count ⇒ ::Integer
Returns Optional. The count of the advertiser's first party data records that have been uploaded to a clean room provider. This does not signify the size of a PAIR user list.
310 311 312 313 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 310 class PairIdInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#clean_room_identifier ⇒ ::String
Returns Required. Immutable. Identifies a unique advertiser to publisher relationship with one clean room provider or across multiple clean room providers.
310 311 312 313 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 310 class PairIdInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#match_rate_percentage ⇒ ::Integer
Returns Required. This field denotes the percentage of membership match of this user list with the corresponding publisher's first party data. Must be between 0 and 100 inclusive.
310 311 312 313 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 310 class PairIdInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#publisher_id ⇒ ::Integer
Returns Required. Immutable. Identifies the publisher that the Publisher Advertiser Identity Reconciliation user list is reconciled with. This field is provided by the cleanroom provider and is only unique in the scope of that cleanroom. This cannot be used as a global identifier across multiple cleanrooms.
310 311 312 313 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 310 class PairIdInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#publisher_name ⇒ ::String
Returns Required. Descriptive name of the publisher to be displayed in the UI for a better targeting experience.
310 311 312 313 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 310 class PairIdInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |