Class: Google::Ads::DataManager::V1::PartnerCustomerAccount
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::PartnerCustomerAccount
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/partner_link_service.rb
Overview
Represents a customer account in the partner's system.
Instance Attribute Summary collapse
-
#account_id ⇒ ::String
Required.
-
#account_name ⇒ ::String
Optional.
-
#account_type ⇒ ::String
Optional.
Instance Attribute Details
#account_id ⇒ ::String
Returns Required. The identifier of the customer account in the partner's ID space.
166 167 168 169 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 166 class PartnerCustomerAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#account_name ⇒ ::String
Returns Optional. The name of the account.
166 167 168 169 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 166 class PartnerCustomerAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#account_type ⇒ ::String
Returns Optional. The type of the account. Can be used to distinguish between advertiser accounts and business level accounts, for example.
166 167 168 169 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 166 class PartnerCustomerAccount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |