Class: Google::Ads::DataManager::V1::PartnerLinkService::Client
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::PartnerLinkService::Client
- Includes:
- Paths
- Defined in:
- lib/google/ads/data_manager/v1/partner_link_service/client.rb
Overview
Client for the PartnerLinkService service.
Service for managing partner links.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the PartnerLinkService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the PartnerLinkService Client instance.
-
#create_partner_link(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::DataManager::V1::PartnerLink
Creates a partner link for the given account.
-
#delete_partner_link(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a partner link for the given account.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new PartnerLinkService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#search_partner_links(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::PartnerLink>
Searches for all partner links to and from a given account.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#account_path, #partner_link_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new PartnerLinkService client object.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 124 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/ads/datamanager/v1/partner_link_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @partner_link_service_stub = ::Gapic::ServiceStub.new( ::Google::Ads::DataManager::V1::PartnerLinkService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @partner_link_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the PartnerLinkService Client class.
See Configuration for a description of the configuration fields.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 62 def self.configure @configure ||= begin namespace = ["Google", "Ads", "DataManager", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the PartnerLinkService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
94 95 96 97 |
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 94 def configure yield @config if block_given? @config end |
#create_partner_link(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::PartnerLink #create_partner_link(parent: nil, partner_link: nil) ⇒ ::Google::Ads::DataManager::V1::PartnerLink
Creates a partner link for the given account.
Authorization Headers:
This method supports the following optional headers to define how the API authorizes access for the request:
login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format:accountTypes/{loginAccountType}/accounts/{loginAccountId}
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 243 def create_partner_link request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::CreatePartnerLinkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_partner_link..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_partner_link.timeout, metadata: , retry_policy: @config.rpcs.create_partner_link.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @partner_link_service_stub.call_rpc :create_partner_link, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_partner_link(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_partner_link(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a partner link for the given account.
Authorization Headers:
This method supports the following optional headers to define how the API authorizes access for the request:
login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format:accountTypes/{loginAccountType}/accounts/{loginAccountId}
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 340 def delete_partner_link request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::DeletePartnerLinkRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_partner_link..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_partner_link.timeout, metadata: , retry_policy: @config.rpcs.delete_partner_link.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @partner_link_service_stub.call_rpc :delete_partner_link, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
180 181 182 |
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 180 def logger @partner_link_service_stub.logger end |
#search_partner_links(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::PartnerLink> #search_partner_links(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::PartnerLink>
Searches for all partner links to and from a given account.
Authorization Headers:
This method supports the following optional headers to define how the API authorizes access for the request:
login-account: (Optional) The resource name of the account where the Google Account of the credentials is a user. If not set, defaults to the account of the request. Format:accountTypes/{loginAccountType}/accounts/{loginAccountId}
479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 479 def search_partner_links request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::SearchPartnerLinksRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.search_partner_links..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.search_partner_links.timeout, metadata: , retry_policy: @config.rpcs.search_partner_links.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @partner_link_service_stub.call_rpc :search_partner_links, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @partner_link_service_stub, :search_partner_links, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
104 105 106 |
# File 'lib/google/ads/data_manager/v1/partner_link_service/client.rb', line 104 def universe_domain @partner_link_service_stub.universe_domain end |