Module: Google::Ads::DataManager::V1::ProcessingWarningReason
- Defined in:
- proto_docs/google/ads/datamanager/v1/processing_errors.rb
Overview
The processing warning reason.
Constant Summary collapse
- PROCESSING_WARNING_REASON_UNSPECIFIED =
The processing warning reason is unknown.
0- PROCESSING_WARNING_REASON_KEK_PERMISSION_DENIED =
The system did not have the permissions needed to access the KEK.
1- PROCESSING_WARNING_REASON_DEK_DECRYPTION_ERROR =
The DEK failed to be decrypted.
2- PROCESSING_WARNING_REASON_DECRYPTION_ERROR =
The event has a decryption error.
3- PROCESSING_WARNING_REASON_WIP_AUTH_FAILED =
The WIP could not be used because it was rejected by its attestation condition.
4- PROCESSING_WARNING_REASON_INVALID_WIP =
The WIP is formatted incorrectly or the WIP does not exist.
5- PROCESSING_WARNING_REASON_INVALID_KEK =
The KEK cannot decrypt data because it is the wrong KEK, or it does not exist.
6- PROCESSING_WARNING_REASON_USER_IDENTIFIER_DECRYPTION_ERROR =
Failed to decrypt th UserIdentifier data using the DEK.
7- PROCESSING_WARNING_REASON_INTERNAL_ERROR =
Internal error.
8- PROCESSING_WARNING_REASON_AWS_AUTH_FAILED =
The system failed to authenticate with AWS.
9