Class: Google::Ads::DataManager::V1::PseudonymousIdInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::PseudonymousIdInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list.rb
Overview
Additional information when PSEUDONYMOUS_ID is one of the
upload_key_types.
Defined Under Namespace
Modules: SyncStatus
Instance Attribute Summary collapse
-
#billable_record_count ⇒ ::Integer
Optional.
-
#sync_status ⇒ ::Google::Ads::DataManager::V1::PseudonymousIdInfo::SyncStatus
readonly
Output only.
Instance Attribute Details
#billable_record_count ⇒ ::Integer
Returns Optional. Immutable. The number of billable records (e.g. uploaded or matched).
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 354 class PseudonymousIdInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Sync status of the user list. module SyncStatus # Not specified. SYNC_STATUS_UNSPECIFIED = 0 # The user list has been created as a placeholder. List contents and/or # metadata are still being synced. The user list is not ready for use. CREATED = 1 # The user list is ready for use. Contents and cookies have been synced # correctly. READY_FOR_USE = 2 # An error has occurred syncing user list contents and/or metadata. The # user list cannot be used. FAILED = 3 end end |
#sync_status ⇒ ::Google::Ads::DataManager::V1::PseudonymousIdInfo::SyncStatus (readonly)
Returns Output only. Sync status of the user list.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 354 class PseudonymousIdInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Sync status of the user list. module SyncStatus # Not specified. SYNC_STATUS_UNSPECIFIED = 0 # The user list has been created as a placeholder. List contents and/or # metadata are still being synced. The user list is not ready for use. CREATED = 1 # The user list is ready for use. Contents and cookies have been synced # correctly. READY_FOR_USE = 2 # An error has occurred syncing user list contents and/or metadata. The # user list cannot be used. FAILED = 3 end end |