Module: Google::Ads::DataManager::V1::PseudonymousIdInfo::SyncStatus
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list.rb
Overview
Sync status of the user list.
Constant Summary collapse
- SYNC_STATUS_UNSPECIFIED =
Not specified.
0- CREATED =
The user list has been created as a placeholder. List contents and/or metadata are still being synced. The user list is not ready for use.
1- READY_FOR_USE =
The user list is ready for use. Contents and cookies have been synced correctly.
2- FAILED =
An error has occurred syncing user list contents and/or metadata. The user list cannot be used.
3