Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestEventsStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestEventsStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the events ingestion to the destination.
Instance Attribute Summary collapse
-
#record_count ⇒ ::Integer
The total count of events sent in the upload request.
Instance Attribute Details
#record_count ⇒ ::Integer
Returns The total count of events sent in the upload request. Includes all events in the request, regardless of whether they were successfully ingested or not.
148 149 150 151 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 148 class IngestEventsStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |