Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestPpidDataStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::IngestPpidDataStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the ppid data ingestion to the destination containing stats related to the ingestion.
Instance Attribute Summary collapse
-
#ppid_count ⇒ ::Integer
The total count of ppids sent in the upload request for the destination.
-
#record_count ⇒ ::Integer
The total count of audience members sent in the upload request for the destination.
Instance Attribute Details
#ppid_count ⇒ ::Integer
Returns The total count of ppids sent in the upload request for the destination. Includes all ppids in the request, regardless of whether they were successfully ingested or not.
278 279 280 281 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 278 class IngestPpidDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#record_count ⇒ ::Integer
Returns The total count of audience members sent in the upload request for the destination. Includes all audience members in the request, regardless of whether they were successfully ingested or not.
278 279 280 281 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 278 class IngestPpidDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |