Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveAudienceMembersStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveAudienceMembersStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the remove audience members request.
Instance Attribute Summary collapse
-
#mobile_data_removal_status ⇒ ::Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveMobileDataStatus
The status of the mobile data removal from the destination.
-
#pair_data_removal_status ⇒ ::Google::Ads::DataManager::V1::RequestStatusPerDestination::RemovePairDataStatus
The status of the pair data removal from the destination.
-
#user_data_removal_status ⇒ ::Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveUserDataStatus
The status of the user data removal from the destination.
Instance Attribute Details
#mobile_data_removal_status ⇒ ::Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveMobileDataStatus
Returns The status of the mobile data removal from the destination.
Note: The following fields are mutually exclusive: mobile_data_removal_status, user_data_removal_status, pair_data_removal_status. If a field in that set is populated, all other fields in the set will automatically be cleared.
95 96 97 98 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 95 class RemoveAudienceMembersStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pair_data_removal_status ⇒ ::Google::Ads::DataManager::V1::RequestStatusPerDestination::RemovePairDataStatus
Returns The status of the pair data removal from the destination.
Note: The following fields are mutually exclusive: pair_data_removal_status, user_data_removal_status, mobile_data_removal_status. If a field in that set is populated, all other fields in the set will automatically be cleared.
95 96 97 98 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 95 class RemoveAudienceMembersStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_data_removal_status ⇒ ::Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveUserDataStatus
Returns The status of the user data removal from the destination.
Note: The following fields are mutually exclusive: user_data_removal_status, mobile_data_removal_status, pair_data_removal_status. If a field in that set is populated, all other fields in the set will automatically be cleared.
95 96 97 98 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 95 class RemoveAudienceMembersStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |