Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveCompositeDataStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveCompositeDataStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the composite data removal from the destination.
Instance Attribute Summary collapse
-
#data_type_counts ⇒ ::Array<::Google::Ads::DataManager::V1::RequestStatusPerDestination::DataTypeCount>
The total count of data types sent in the removal request, broken down by data type.
-
#record_count ⇒ ::Integer
The total count of audience members sent in the removal request.
Instance Attribute Details
#data_type_counts ⇒ ::Array<::Google::Ads::DataManager::V1::RequestStatusPerDestination::DataTypeCount>
Returns The total count of data types sent in the removal request, broken down by data type. Includes all data types in the request, regardless of whether they were successfully removed or not.
353 354 355 356 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 353 class RemoveCompositeDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#record_count ⇒ ::Integer
Returns The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not.
353 354 355 356 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 353 class RemoveCompositeDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |