Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveMobileDataStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveMobileDataStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the mobile data removal from the destination.
Instance Attribute Summary collapse
-
#mobile_id_count ⇒ ::Integer
The total count of mobile Ids sent in the removal request.
-
#record_count ⇒ ::Integer
The total count of audience members sent in the removal request.
Instance Attribute Details
#mobile_id_count ⇒ ::Integer
Returns The total count of mobile Ids sent in the removal request. Includes all mobile ids in the request, regardless of whether they were successfully removed or not.
217 218 219 220 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 217 class RemoveMobileDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#record_count ⇒ ::Integer
Returns The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not.
217 218 219 220 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 217 class RemoveMobileDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |