Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::RemovePpidDataStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb

Overview

The status of the ppid data removal from the destination.

Instance Attribute Summary collapse

Instance Attribute Details

#ppid_count::Integer

Returns The total count of ppids sent in the removal request. Includes all ppids in the request, regardless of whether they were successfully removed or not.

Returns:

  • (::Integer)

    The total count of ppids sent in the removal request. Includes all ppids in the request, regardless of whether they were successfully removed or not.



306
307
308
309
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 306

class RemovePpidDataStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#record_count::Integer

Returns The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not.

Returns:

  • (::Integer)

    The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not.



306
307
308
309
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 306

class RemovePpidDataStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end