Class: Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveUserDataStatus
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RequestStatusPerDestination::RemoveUserDataStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb
Overview
The status of the user data removal from the destination.
Instance Attribute Summary collapse
-
#record_count ⇒ ::Integer
The total count of audience members sent in the removal request.
-
#user_identifier_count ⇒ ::Integer
The total count of user identifiers sent in the removal request.
Instance Attribute Details
#record_count ⇒ ::Integer
Returns The total count of audience members sent in the removal request. Includes all audience members in the request, regardless of whether they were successfully removed or not.
174 175 176 177 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 174 class RemoveUserDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_identifier_count ⇒ ::Integer
Returns The total count of user identifiers sent in the removal request. Includes all user identifiers in the request, regardless of whether they were successfully removed or not.
174 175 176 177 |
# File 'proto_docs/google/ads/datamanager/v1/request_status_per_destination.rb', line 174 class RemoveUserDataStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |