Class: Google::Ads::DataManager::V1::RetrieveInsightsResponse::MarketingDataInsight::MarketingDataInsightsAttribute
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::RetrieveInsightsResponse::MarketingDataInsight::MarketingDataInsightsAttribute
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/insights_service.rb
Overview
Insights for a collection of related attributes of the same dimension.
Instance Attribute Summary collapse
-
#age_range ⇒ ::Google::Ads::DataManager::V1::AgeRange
Age range of the audience for which the lift is provided.
-
#gender ⇒ ::Google::Ads::DataManager::V1::Gender
Gender of the audience for which the lift is provided.
-
#lift ⇒ ::Float
Measure of lift that the audience has for the attribute value as compared to the baseline.
-
#user_interest_id ⇒ ::Integer
The user interest ID.
Instance Attribute Details
#age_range ⇒ ::Google::Ads::DataManager::V1::AgeRange
Returns Age range of the audience for which the lift is provided.
103 104 105 106 |
# File 'proto_docs/google/ads/datamanager/v1/insights_service.rb', line 103 class MarketingDataInsightsAttribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gender ⇒ ::Google::Ads::DataManager::V1::Gender
Returns Gender of the audience for which the lift is provided.
103 104 105 106 |
# File 'proto_docs/google/ads/datamanager/v1/insights_service.rb', line 103 class MarketingDataInsightsAttribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#lift ⇒ ::Float
Returns Measure of lift that the audience has for the attribute value as compared to the baseline. Range [0-1].
103 104 105 106 |
# File 'proto_docs/google/ads/datamanager/v1/insights_service.rb', line 103 class MarketingDataInsightsAttribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_interest_id ⇒ ::Integer
Returns The user interest ID.
103 104 105 106 |
# File 'proto_docs/google/ads/datamanager/v1/insights_service.rb', line 103 class MarketingDataInsightsAttribute include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |