Class: Google::Ads::DataManager::V1::SearchPartnerLinksRequest
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::SearchPartnerLinksRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/partner_link_service.rb
Overview
Request to search for PartnerLink resources. Returns a SearchPartnerLinksResponse.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
The maximum number of partner links to return.
-
#page_token ⇒ ::String
A page token, received from a previous
SearchPartnerLinkscall. -
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. A filter string. All fields need to
be on the left hand side of each condition (for example: partner_link_id =
123456789). Fields must be specified using either all camel
case or all snake
case. Don't use a combination of
camel case and snake case.
Supported operations:
AND=!=
Supported fields:
partner_link_idowning_account.account_typeowning_account.account_idpartner_account.account_typepartner_account.account_id
Example:
owning_account.account_type = "GOOGLE_ADS" AND partner_account.account_id
= 987654321.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 100 class SearchPartnerLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns The maximum number of partner links to return. The service may return fewer than this value. If unspecified, at most 10 partner links will be returned. The maximum value is 100; values above 100 will be coerced to 100.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 100 class SearchPartnerLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A page token, received from a previous SearchPartnerLinks call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to SearchPartnerLinks
must match the call that provided the page token.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 100 class SearchPartnerLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Account to search for partner links. If no filter is specified,
all partner links where this account is either the owning_account or
partner_account are returned.
Format: accountTypes/{account_type}/accounts/{account}.
100 101 102 103 |
# File 'proto_docs/google/ads/datamanager/v1/partner_link_service.rb', line 100 class SearchPartnerLinksRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |