Class: Google::Ads::DataManager::V1::TargetNetworkInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::TargetNetworkInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list.rb
Overview
Eligibility information for different target networks.
Instance Attribute Summary collapse
-
#eligible_for_display ⇒ ::Boolean
readonly
Output only.
-
#eligible_for_search ⇒ ::Boolean
Optional.
Instance Attribute Details
#eligible_for_display ⇒ ::Boolean (readonly)
Returns Output only. Indicates this user list is eligible for Google Display Network.
162 163 164 165 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 162 class TargetNetworkInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#eligible_for_search ⇒ ::Boolean
Returns Optional. Indicates if this user list is eligible for Google Search Network.
162 163 164 165 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 162 class TargetNetworkInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |