Class: Google::Ads::DataManager::V1::TermsOfService
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::TermsOfService
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/terms_of_service.rb
Overview
The terms of service that the user has accepted/rejected.
Instance Attribute Summary collapse
-
#customer_match_terms_of_service_status ⇒ ::Google::Ads::DataManager::V1::TermsOfServiceStatus
Optional.
Instance Attribute Details
#customer_match_terms_of_service_status ⇒ ::Google::Ads::DataManager::V1::TermsOfServiceStatus
Returns Optional. The Customer Match terms of service: https://support.google.com/adspolicy/answer/6299717. This must be accepted when ingesting UserData or MobileData. This field is not required for Partner Match User list.
33 34 35 36 |
# File 'proto_docs/google/ads/datamanager/v1/terms_of_service.rb', line 33 class TermsOfService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |