Class: Google::Ads::DataManager::V1::UserList
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::UserList
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list.rb
Overview
A user list resource.
Defined Under Namespace
Modules: AccessReason, AccessStatus, ClosingReason, MembershipStatus
Instance Attribute Summary collapse
-
#access_reason ⇒ ::Google::Ads::DataManager::V1::UserList::AccessReason
readonly
Output only.
-
#account_access_status ⇒ ::Google::Ads::DataManager::V1::UserList::AccessStatus
Optional.
-
#closing_reason ⇒ ::Google::Ads::DataManager::V1::UserList::ClosingReason
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#id ⇒ ::Integer
readonly
Output only.
-
#ingested_user_list_info ⇒ ::Google::Ads::DataManager::V1::IngestedUserListInfo
Optional.
-
#integration_code ⇒ ::String
Optional.
-
#membership_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#membership_status ⇒ ::Google::Ads::DataManager::V1::UserList::MembershipStatus
Optional.
-
#name ⇒ ::String
Identifier.
-
#read_only ⇒ ::Boolean
readonly
Output only.
-
#size_info ⇒ ::Google::Ads::DataManager::V1::SizeInfo
readonly
Output only.
-
#target_network_info ⇒ ::Google::Ads::DataManager::V1::TargetNetworkInfo
Optional.
Instance Attribute Details
#access_reason ⇒ ::Google::Ads::DataManager::V1::UserList::AccessReason (readonly)
Returns Output only. The reason this account has been granted access to the list.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#account_access_status ⇒ ::Google::Ads::DataManager::V1::UserList::AccessStatus
Returns Optional. Indicates if this share is still enabled. When a user list is
shared with the account this field is set to ENABLED. Later the user list
owner can decide to revoke the share and make it DISABLED.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#closing_reason ⇒ ::Google::Ads::DataManager::V1::UserList::ClosingReason (readonly)
Returns Output only. The reason why this user list membership status is closed.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#description ⇒ ::String
Returns Optional. A description of the user list.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#display_name ⇒ ::String
Returns Required. The display name of the user list.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#id ⇒ ::Integer (readonly)
Returns Output only. The unique ID of the user list.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#ingested_user_list_info ⇒ ::Google::Ads::DataManager::V1::IngestedUserListInfo
Returns Optional. Represents a user list that is populated by user ingested data.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#integration_code ⇒ ::String
Returns Optional. An ID from external system. It is used by user list sellers to correlate IDs on their systems.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#membership_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration a user remains in the user list. Valid durations are exact multiples of 24 hours (86400 seconds). Providing a value that is not an exact multiple of 24 hours will result in an INVALID_ARGUMENT error.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#membership_status ⇒ ::Google::Ads::DataManager::V1::UserList::MembershipStatus
Returns Optional. Membership status of this user list.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#name ⇒ ::String
Returns Identifier. The resource name of the user list. Format: accountTypes/{account_type}/accounts/{account}/userLists/{user_list}.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#read_only ⇒ ::Boolean (readonly)
Returns Output only. An option that indicates if a user may edit a list.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#size_info ⇒ ::Google::Ads::DataManager::V1::SizeInfo (readonly)
Returns Output only. Estimated number of members in this user list in different target networks.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |
#target_network_info ⇒ ::Google::Ads::DataManager::V1::TargetNetworkInfo
Returns Optional. Eligibility information for different target networks.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'proto_docs/google/ads/datamanager/v1/user_list.rb', line 76 class UserList include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Status of the user list. module MembershipStatus # Not specified. MEMBERSHIP_STATUS_UNSPECIFIED = 0 # Open status - User list is accruing members and can be targeted to. OPEN = 1 # Closed status - No new members being added. CLOSED = 2 end # Indicates the reason why the user list was closed. # This enum is only used when a list is auto-closed by the system. module ClosingReason # Not specified. CLOSING_REASON_UNSPECIFIED = 0 # The user list was closed because it has not been used in targeting # recently. See https://support.google.com/google-ads/answer/2472738 # for details. UNUSED = 1 end # Enum describing possible access reasons. module AccessReason # Not specified. ACCESS_REASON_UNSPECIFIED = 0 # The resource is owned by the user. OWNED = 1 # The resource is shared to the user. SHARED = 2 # The resource is licensed to the user. LICENSED = 3 # The user subscribed to the resource. SUBSCRIBED = 4 # The resource is accessible to the user. AFFILIATED = 5 end # Indicates if this client still has access to the list. module AccessStatus # Not specified. ACCESS_STATUS_UNSPECIFIED = 0 # The access is enabled. ENABLED = 1 # The access is disabled. DISABLED = 2 end end |