Class: Google::Ads::DataManager::V1::UserListDirectLicense
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::UserListDirectLicense
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb
Overview
A user list direct license.
This feature is only available to data partners.
Instance Attribute Summary collapse
-
#client_account_display_name ⇒ ::String
readonly
Output only.
-
#client_account_id ⇒ ::Integer
Immutable.
-
#client_account_type ⇒ ::Google::Ads::DataManager::V1::UserListLicenseClientAccountType
Immutable.
-
#historical_pricings ⇒ ::Array<::Google::Ads::DataManager::V1::UserListLicensePricing>
readonly
Output only.
-
#metrics ⇒ ::Google::Ads::DataManager::V1::UserListLicenseMetrics
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#pricing ⇒ ::Google::Ads::DataManager::V1::UserListLicensePricing
Optional.
-
#status ⇒ ::Google::Ads::DataManager::V1::UserListLicenseStatus
Optional.
-
#user_list_display_name ⇒ ::String
readonly
Output only.
-
#user_list_id ⇒ ::Integer
Immutable.
Instance Attribute Details
#client_account_display_name ⇒ ::String (readonly)
Returns Output only. Name of client customer which the user list is being licensed to.
This field is read-only.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_account_id ⇒ ::Integer
Returns Immutable. ID of client customer which the user list is being licensed to.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#client_account_type ⇒ ::Google::Ads::DataManager::V1::UserListLicenseClientAccountType
Returns Immutable. Account type of client customer which the user list is being licensed to.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#historical_pricings ⇒ ::Array<::Google::Ads::DataManager::V1::UserListLicensePricing> (readonly)
Returns Output only. Pricing history of this user list license.
This field is read-only.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metrics ⇒ ::Google::Ads::DataManager::V1::UserListLicenseMetrics (readonly)
Returns Output only. Metrics related to this license
This field is read-only and only populated if the start and end dates are set in the ListUserListDirectLicenses call.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the user list direct license.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pricing ⇒ ::Google::Ads::DataManager::V1::UserListLicensePricing
Returns Optional. UserListDirectLicense pricing.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Ads::DataManager::V1::UserListLicenseStatus
Returns Optional. Status of UserListDirectLicense - ENABLED or DISABLED.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_list_display_name ⇒ ::String (readonly)
Returns Output only. Name of the user list being licensed.
This field is read-only.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#user_list_id ⇒ ::Integer
Returns Immutable. ID of the user list being licensed.
68 69 70 71 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_direct_license.rb', line 68 class UserListDirectLicense include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |