Class: Google::Ads::DataManager::V1::UserListDirectLicenseService::Client
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::UserListDirectLicenseService::Client
- Includes:
- Paths
- Defined in:
- lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb
Overview
Client for the UserListDirectLicenseService service.
Service for managing user list direct licenses. Delete is not a supported operation for UserListDirectLicenses. Callers should update the license status to DISABLED to instead to deactivate a license.
This feature is only available to data partners.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the UserListDirectLicenseService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the UserListDirectLicenseService Client instance.
-
#create_user_list_direct_license(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Creates a user list direct license.
-
#get_user_list_direct_license(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Retrieves a user list direct license.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new UserListDirectLicenseService client object.
-
#list_user_list_direct_licenses(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListDirectLicense>
Lists all user list direct licenses owned by the parent account.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_user_list_direct_license(request, options = nil) {|response, operation| ... } ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Updates a user list direct license.
Methods included from Paths
#account_path, #user_list_direct_license_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new UserListDirectLicenseService client object.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 128 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/ads/datamanager/v1/user_list_direct_license_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @user_list_direct_license_service_stub = ::Gapic::ServiceStub.new( ::Google::Ads::DataManager::V1::UserListDirectLicenseService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @user_list_direct_license_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the UserListDirectLicenseService Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 66 def self.configure @configure ||= begin namespace = ["Google", "Ads", "DataManager", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the UserListDirectLicenseService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
98 99 100 101 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 98 def configure yield @config if block_given? @config end |
#create_user_list_direct_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense #create_user_list_direct_license(parent: nil, user_list_direct_license: nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Creates a user list direct license.
This feature is only available to data partners.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 239 def create_user_list_direct_license request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::CreateUserListDirectLicenseRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_user_list_direct_license..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_user_list_direct_license.timeout, metadata: , retry_policy: @config.rpcs.create_user_list_direct_license.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @user_list_direct_license_service_stub.call_rpc :create_user_list_direct_license, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_user_list_direct_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense #get_user_list_direct_license(name: nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Retrieves a user list direct license.
This feature is only available to data partners.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 326 def get_user_list_direct_license request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::GetUserListDirectLicenseRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_user_list_direct_license..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_user_list_direct_license.timeout, metadata: , retry_policy: @config.rpcs.get_user_list_direct_license.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @user_list_direct_license_service_stub.call_rpc :get_user_list_direct_license, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_user_list_direct_licenses(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListDirectLicense> #list_user_list_direct_licenses(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Ads::DataManager::V1::UserListDirectLicense>
Lists all user list direct licenses owned by the parent account.
This feature is only available to data partners.
546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 546 def list_user_list_direct_licenses request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::ListUserListDirectLicensesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_user_list_direct_licenses..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_user_list_direct_licenses.timeout, metadata: , retry_policy: @config.rpcs.list_user_list_direct_licenses.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @user_list_direct_license_service_stub.call_rpc :list_user_list_direct_licenses, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @user_list_direct_license_service_stub, :list_user_list_direct_licenses, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
184 185 186 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 184 def logger @user_list_direct_license_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
108 109 110 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 108 def universe_domain @user_list_direct_license_service_stub.universe_domain end |
#update_user_list_direct_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense #update_user_list_direct_license(user_list_direct_license: nil, update_mask: nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Updates a user list direct license.
This feature is only available to data partners.
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/client.rb', line 417 def update_user_list_direct_license request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::UpdateUserListDirectLicenseRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_user_list_direct_license..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.user_list_direct_license&.name header_params["user_list_direct_license.name"] = request.user_list_direct_license.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_user_list_direct_license.timeout, metadata: , retry_policy: @config.rpcs.update_user_list_direct_license.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @user_list_direct_license_service_stub.call_rpc :update_user_list_direct_license, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |