Class: Google::Ads::DataManager::V1::UserListDirectLicenseService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::UserListDirectLicenseService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb
Overview
REST client for the UserListDirectLicenseService service.
Service for managing user list direct licenses. Delete is not a supported operation for UserListDirectLicenses. Callers should update the license status to DISABLED to instead to deactivate a license.
This feature is only available to data partners.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the UserListDirectLicenseService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the UserListDirectLicenseService Client instance.
-
#create_user_list_direct_license(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Creates a user list direct license.
-
#get_user_list_direct_license(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Retrieves a user list direct license.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new UserListDirectLicenseService REST client object.
-
#list_user_list_direct_licenses(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListDirectLicense>
Lists all user list direct licenses owned by the parent account.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_user_list_direct_license(request, options = nil) {|result, operation| ... } ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Updates a user list direct license.
Methods included from Paths
#account_path, #user_list_direct_license_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new UserListDirectLicenseService REST client object.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 130 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @user_list_direct_license_service_stub = ::Google::Ads::DataManager::V1::UserListDirectLicenseService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @user_list_direct_license_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the UserListDirectLicenseService Client class.
See Configuration for a description of the configuration fields.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 68 def self.configure @configure ||= begin namespace = ["Google", "Ads", "DataManager", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the UserListDirectLicenseService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
100 101 102 103 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 100 def configure yield @config if block_given? @config end |
#create_user_list_direct_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense #create_user_list_direct_license(parent: nil, user_list_direct_license: nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Creates a user list direct license.
This feature is only available to data partners.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 231 def create_user_list_direct_license request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::CreateUserListDirectLicenseRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_user_list_direct_license..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_user_list_direct_license.timeout, metadata: , retry_policy: @config.rpcs.create_user_list_direct_license.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @user_list_direct_license_service_stub.create_user_list_direct_license request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_user_list_direct_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense #get_user_list_direct_license(name: nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Retrieves a user list direct license.
This feature is only available to data partners.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 311 def get_user_list_direct_license request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::GetUserListDirectLicenseRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_user_list_direct_license..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_user_list_direct_license.timeout, metadata: , retry_policy: @config.rpcs.get_user_list_direct_license.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @user_list_direct_license_service_stub.get_user_list_direct_license request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_user_list_direct_licenses(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListDirectLicense> #list_user_list_direct_licenses(parent: nil, filter: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Ads::DataManager::V1::UserListDirectLicense>
Lists all user list direct licenses owned by the parent account.
This feature is only available to data partners.
517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 517 def list_user_list_direct_licenses request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::ListUserListDirectLicensesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_user_list_direct_licenses..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_user_list_direct_licenses.timeout, metadata: , retry_policy: @config.rpcs.list_user_list_direct_licenses.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @user_list_direct_license_service_stub.list_user_list_direct_licenses request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @user_list_direct_license_service_stub, :list_user_list_direct_licenses, "user_list_direct_licenses", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
177 178 179 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 177 def logger @user_list_direct_license_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
110 111 112 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 110 def universe_domain @user_list_direct_license_service_stub.universe_domain end |
#update_user_list_direct_license(request, options = nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense #update_user_list_direct_license(user_list_direct_license: nil, update_mask: nil) ⇒ ::Google::Ads::DataManager::V1::UserListDirectLicense
Updates a user list direct license.
This feature is only available to data partners.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/google/ads/data_manager/v1/user_list_direct_license_service/rest/client.rb', line 395 def update_user_list_direct_license request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Ads::DataManager::V1::UpdateUserListDirectLicenseRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_user_list_direct_license..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Ads::DataManager::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_user_list_direct_license.timeout, metadata: , retry_policy: @config.rpcs.update_user_list_direct_license.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @user_list_direct_license_service_stub.update_user_list_direct_license request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |