Class: Google::Ads::DataManager::V1::UserListLicensePricing
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::UserListLicensePricing
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb
Overview
A user list license pricing.
Defined Under Namespace
Modules: UserListPricingBuyerApprovalState, UserListPricingCostType
Instance Attribute Summary collapse
-
#buyer_approval_state ⇒ ::Google::Ads::DataManager::V1::UserListLicensePricing::UserListPricingBuyerApprovalState
readonly
Output only.
-
#cost_micros ⇒ ::Integer
Optional.
-
#cost_type ⇒ ::Google::Ads::DataManager::V1::UserListLicensePricing::UserListPricingCostType
Immutable.
-
#currency_code ⇒ ::String
Optional.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#max_cost_micros ⇒ ::Integer
Optional.
-
#pricing_active ⇒ ::Boolean
readonly
Output only.
-
#pricing_id ⇒ ::Integer
readonly
Output only.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#buyer_approval_state ⇒ ::Google::Ads::DataManager::V1::UserListLicensePricing::UserListPricingBuyerApprovalState (readonly)
Returns Output only. The buyer approval state of this pricing.
This field is read-only.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |
#cost_micros ⇒ ::Integer
Returns Optional. The cost associated with the model, in micro units (10^-6), in
the currency specified by the currency_code field. For example, 2000000
means $2 if currency_code is USD.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |
#cost_type ⇒ ::Google::Ads::DataManager::V1::UserListLicensePricing::UserListPricingCostType
Returns Immutable. The cost type of this pricing.
Can be set only in the create operation. Can't be updated for
an existing license.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |
#currency_code ⇒ ::String
Returns Optional. The currency in which cost and max_cost is specified. Must be a three-letter currency code defined in ISO 4217.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. End time of the pricing.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |
#max_cost_micros ⇒ ::Integer
Returns Optional. The maximum CPM a commerce audience can be charged when the
MEDIA_SHARE cost type is used. The value is in micro units (10^-6) and in
the currency specified by the currency_code field. For example, 2000000
means $2 if currency_code is USD.
This is only relevant when cost_type is MEDIA_SHARE.
When cost_type is not MEDIA_SHARE, and this field is set, a
MAX_COST_NOT_ALLOWED error will be returned.
If not set or set to0, there is no cap.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |
#pricing_active ⇒ ::Boolean (readonly)
Returns Output only. Whether this pricing is active.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |
#pricing_id ⇒ ::Integer (readonly)
Returns Output only. The ID of this pricing.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Start time of the pricing.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb', line 68 class UserListLicensePricing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # User list pricing buyer approval state. module UserListPricingBuyerApprovalState # UNSPECIFIED. USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED = 0 # User list client has not yet accepted the pricing terms set by the user # list owner. PENDING = 1 # User list client has accepted the pricing terms set by the user list # owner. APPROVED = 2 # User list client has rejected the pricing terms set by the user list # owner. REJECTED = 3 end # User list pricing cost type. module UserListPricingCostType # Unspecified. USER_LIST_PRICING_COST_TYPE_UNSPECIFIED = 0 # Cost per click. CPC = 1 # Cost per mille (thousand impressions). CPM = 2 # Media share. MEDIA_SHARE = 3 end end |