Module: Google::Ads::DataManager::V1::UserListLicensePricing::UserListPricingBuyerApprovalState
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_list_license_pricing.rb
Overview
User list pricing buyer approval state.
Constant Summary collapse
- USER_LIST_PRICING_BUYER_APPROVAL_STATE_UNSPECIFIED =
UNSPECIFIED.
0- PENDING =
User list client has not yet accepted the pricing terms set by the user list owner.
1- APPROVED =
User list client has accepted the pricing terms set by the user list owner.
2- REJECTED =
User list client has rejected the pricing terms set by the user list owner.
3