Class: Google::Ads::DataManager::V1::UserProperties
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::UserProperties
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_properties.rb
Overview
Advertiser-assessed information about the user at the time that the event happened. See https://support.google.com/google-ads/answer/14007601 for more details.
Instance Attribute Summary collapse
-
#additional_user_properties ⇒ ::Array<::Google::Ads::DataManager::V1::UserProperty>
Optional.
-
#customer_type ⇒ ::Google::Ads::DataManager::V1::CustomerType
Optional.
-
#customer_value_bucket ⇒ ::Google::Ads::DataManager::V1::CustomerValueBucket
Optional.
Instance Attribute Details
#additional_user_properties ⇒ ::Array<::Google::Ads::DataManager::V1::UserProperty>
Returns Optional. A bucket of any additional user properties for the user associated with this event.
38 39 40 41 |
# File 'proto_docs/google/ads/datamanager/v1/user_properties.rb', line 38 class UserProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#customer_type ⇒ ::Google::Ads::DataManager::V1::CustomerType
Returns Optional. Type of the customer associated with the event.
38 39 40 41 |
# File 'proto_docs/google/ads/datamanager/v1/user_properties.rb', line 38 class UserProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#customer_value_bucket ⇒ ::Google::Ads::DataManager::V1::CustomerValueBucket
Returns Optional. The advertiser-assessed value of the customer.
38 39 40 41 |
# File 'proto_docs/google/ads/datamanager/v1/user_properties.rb', line 38 class UserProperties include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |