Class: Google::Ads::DataManager::V1::UserProperty
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::UserProperty
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/user_properties.rb
Overview
A bucket of any additional user properties for the user associated with this event.
Instance Attribute Summary collapse
-
#property_name ⇒ ::String
Required.
-
#value ⇒ ::String
Required.
Instance Attribute Details
#property_name ⇒ ::String
Returns Required. The name of the user property to use.
53 54 55 56 |
# File 'proto_docs/google/ads/datamanager/v1/user_properties.rb', line 53 class UserProperty include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#value ⇒ ::String
Returns Required. The string representation of the value of the user property to use.
53 54 55 56 |
# File 'proto_docs/google/ads/datamanager/v1/user_properties.rb', line 53 class UserProperty include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |