Class: Google::Ads::DataManager::V1::ViewabilityInfo
- Inherits:
-
Object
- Object
- Google::Ads::DataManager::V1::ViewabilityInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/ads/datamanager/v1/viewability_info.rb
Overview
Details of the viewability of the ad served.
Instance Attribute Summary collapse
-
#media_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#media_quartile ⇒ ::Google::Ads::DataManager::V1::MediaQuartile
Optional.
-
#media_skippable ⇒ ::Boolean
Optional.
-
#media_volume_percent ⇒ ::Integer
Optional.
-
#playback_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#view_type ⇒ ::Google::Ads::DataManager::V1::ViewType
Required.
-
#viewable_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#viewable_percent ⇒ ::Integer
Optional.
Instance Attribute Details
#media_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration of the ad media.
51 52 53 54 |
# File 'proto_docs/google/ads/datamanager/v1/viewability_info.rb', line 51 class ViewabilityInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#media_quartile ⇒ ::Google::Ads::DataManager::V1::MediaQuartile
Returns Optional. The amount of the media that was played as discrete quartiles.
51 52 53 54 |
# File 'proto_docs/google/ads/datamanager/v1/viewability_info.rb', line 51 class ViewabilityInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#media_skippable ⇒ ::Boolean
Returns Optional. Whether the ad media was skippable or not.
51 52 53 54 |
# File 'proto_docs/google/ads/datamanager/v1/viewability_info.rb', line 51 class ViewabilityInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#media_volume_percent ⇒ ::Integer
Returns Optional. The numerical percent (0-100) of the volume of the media playback.
51 52 53 54 |
# File 'proto_docs/google/ads/datamanager/v1/viewability_info.rb', line 51 class ViewabilityInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#playback_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The duration of playback of the ad media, regardless of whether it was viewable or not.
51 52 53 54 |
# File 'proto_docs/google/ads/datamanager/v1/viewability_info.rb', line 51 class ViewabilityInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view_type ⇒ ::Google::Ads::DataManager::V1::ViewType
Returns Required. The type of the event.
51 52 53 54 |
# File 'proto_docs/google/ads/datamanager/v1/viewability_info.rb', line 51 class ViewabilityInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#viewable_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The amount of time the ad was viewable for.
51 52 53 54 |
# File 'proto_docs/google/ads/datamanager/v1/viewability_info.rb', line 51 class ViewabilityInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#viewable_percent ⇒ ::Integer
Returns Optional. The numerical percent (0-100) of the pixels that were viewable.
51 52 53 54 |
# File 'proto_docs/google/ads/datamanager/v1/viewability_info.rb', line 51 class ViewabilityInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |